@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameMusic.cpp,v 1.28 2009/06/21 13:47:44 bowkenken Exp $
+* $Id: GameMusic.cpp,v 1.31 2010/01/31 16:59:40 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -47,7 +47,7 @@
 static int audioRate = 22050;
 static unsigned short audioFormat = AUDIO_S16;
 static int audioChannels = 2;
-static int audioBuffers = 4096;
+static int audioBuffers = 1024;
 #endif
 
 ////////////////////////////////////////////////////////////////
@@ -186,6 +186,10 @@ void GameMusic::init()
 			"effect/inn/" );
 	initLsMusic( &(lsEffect[ME_KIND_TEMPLE]),
 			"effect/temple/" );
+
+	// 
+
+	setVolume( get_music_volume_rate() );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -236,6 +240,17 @@ void GameMusic::close()
 #endif
 }
 
+////////////////////////////////////////////////////////////////
+// BGM β̤
+////////////////////////////////////////////////////////////////
+
+void GameMusic::setVolume( rate_t rate )
+{
+#ifdef	HAVE_SDL_SDL_MIXER_H
+	Mix_VolumeMusic( MIX_MAX_VOLUME * rate / _100_PERCENT );
+#endif
+}
+
 ////////////////////////////////////////////////////////////////
 // ˹礻 BGM κ
 ////////////////////////////////////////////////////////////////
