@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw.h,v 1.68 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: draw.h,v 1.72 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_H
@@ -114,12 +114,12 @@
 #define	WIN_REQUEST_DRAW_WIDTH	40
 #define	WIN_REQUEST_DRAW_MIN_Y	4
 
-#define	WIN_STAT_DRAW_MIN_X	(WIN_MAP_DRAW_MAX_X + 1 + 1)
+#define	WIN_STAT_DRAW_MIN_X	(get_map_col() + 1)
 #define	WIN_STAT_DRAW_MIN_Y	0
-#define	WIN_STAT_DRAW_WIDTH	\
-		(WIN_STAT_DRAW_MAX_X - WIN_STAT_DRAW_MIN_X + 1)
+#define	WIN_STAT_DRAW_WIDTH	(SCREEN_WIDTH / 2 - 2)
 #define	WIN_STAT_DRAW_HEIGHT	3
-#define	WIN_STAT_DRAW_MAX_X	(SCREEN_WIDTH - 1 - 1)
+#define	WIN_STAT_DRAW_MAX_X	\
+		(WIN_STAT_DRAW_MIN_X + WIN_STAT_DRAW_WIDTH - 1)
 #define	WIN_STAT_DRAW_MAX_Y	(WIN_STAT_DRAW_MIN_Y \
 		+ ((MBR_MAX_N) * WIN_STAT_DRAW_HEIGHT - 1) - 1)
 
@@ -242,6 +242,117 @@ typedef unsigned long	flg_vfx_mnstr_t;
 /* ơ֥Υ */
 #define	KEY_TAB_MAX_N	512
 
+/***************************************************************
+* ե󥯥󡦥
+***************************************************************/
+
+/* ܥֹ椫饭ؤѴ */
+
+#define	KEY_N_ALL( fn )	(KEY_N_0 + (fn))
+#define	KEY_N_FUNC( fn )	(KEY_N_FUNC_0 + (fn))
+#define	KEY_N_MOUSE_CLICK( fn )	(KEY_N_MOUSE_CLICK_0 + (fn))
+#define	KEY_N_MOUSE_D_CLICK( fn )	(KEY_N_MOUSE_D_CLICK_0 + (fn))
+#define	KEY_N_MOUSE_P_CLICK( fn )	(KEY_N_MOUSE_P_CLICK_0 + (fn))
+#define	KEY_N_MOUSE_PRESS( fn )	(KEY_N_MOUSE_PRESS_0 + (fn))
+#define	KEY_N_MOUSE_RELEASE( fn )	(KEY_N_MOUSE_RELEASE_0 + (fn))
+#define	KEY_N_MOUSE_MOTION( fn )	(KEY_N_MOUSE_MOTION_0 + (fn))
+#define	KEY_N_JOYSTICK( fn )	(KEY_N_JOYSTICK_0 + (fn))
+
+/* ޥΥܥֹ */
+
+typedef enum {
+	KEY_N_MOUSE_0,
+	KEY_N_MOUSE_1,
+	KEY_N_MOUSE_2,
+	KEY_N_MOUSE_3,
+	KEY_N_MOUSE_4,
+	KEY_N_MOUSE_5,
+	KEY_N_MOUSE_6,
+	KEY_N_MOUSE_7,
+	KEY_N_MOUSE_8,
+	KEY_N_MOUSE_9,
+
+	KEY_N_MOUSE_L = KEY_N_MOUSE_0,
+	KEY_N_MOUSE_M = KEY_N_MOUSE_1,
+	KEY_N_MOUSE_R = KEY_N_MOUSE_2,
+
+	KEY_N_MOUSE_PRESS_L_CLICK_R = KEY_N_MOUSE_0,
+	KEY_N_MOUSE_PRESS_R_CLICK_L = KEY_N_MOUSE_1,
+
+	KEY_N_MOUSE_MOTION_LEFT = KEY_N_MOUSE_0,
+	KEY_N_MOUSE_MOTION_RIGHT = KEY_N_MOUSE_1,
+	KEY_N_MOUSE_MOTION_UP = KEY_N_MOUSE_2,
+	KEY_N_MOUSE_MOTION_DOWN = KEY_N_MOUSE_3,
+} key_n_mouse_t;
+
+/* ե󥯥󡦥󥹤ϰϡͽΰޤ */
+
+typedef enum {
+	KEY_N_0 = 0x1000,
+
+	KEY_N_FUNC_0 = 0x1000,
+	KEY_N_FUNC_MAX = 0x10ff,
+
+	KEY_N_MOUSE_CLICK_0 = 0x1100,
+	KEY_N_MOUSE_CLICK_MAX = 0x11ff,
+
+	KEY_N_MOUSE_D_CLICK_0 = 0x1200,
+	KEY_N_MOUSE_D_CLICK_MAX = 0x12ff,
+
+	KEY_N_MOUSE_P_CLICK_0 = 0x1300,
+	KEY_N_MOUSE_P_CLICK_MAX = 0x13ff,
+
+	KEY_N_MOUSE_PRESS_0 = 0x1400,
+	KEY_N_MOUSE_PRESS_MAX = 0x14ff,
+
+	KEY_N_MOUSE_RELEASE_0 = 0x1500,
+	KEY_N_MOUSE_RELEASE_MAX = 0x15ff,
+
+	KEY_N_MOUSE_MOTION_0 = 0x1600,
+	KEY_N_MOUSE_MOTION_MAX = 0x16ff,
+
+	KEY_N_JOYSTICK_0 = 0x1700,
+	KEY_N_JOYSTICK_MAX = 0x17ff,
+
+	KEY_N_MAX = 0x1fff,
+} key_n_t;
+
+/* ե󥯥󡦥󥹤λѤƤ륭ο */
+
+#define	KEY_N_FUNC_MAX_N	48
+#define	KEY_N_MOUSE_CLICK_MAX_N	10
+#define	KEY_N_MOUSE_D_CLICK_MAX_N	10
+#define	KEY_N_MOUSE_P_CLICK_MAX_N	10
+#define	KEY_N_MOUSE_PRESS_MAX_N	10
+#define	KEY_N_MOUSE_RELEASE_MAX_N	10
+#define	KEY_N_MOUSE_MOTION_MAX_N	10
+#define	KEY_N_JOYSTICK_MAX_N	20
+
+/* ƬΥǥå */
+
+#define	KEY_N_FUNC_HEAD_N	0
+#define	KEY_N_MOUSE_HEAD_N	KEY_N_FUNC_MAX_N
+#define	KEY_N_JOYSTICK_HEAD_N	(KEY_N_FUNC_MAX_N + KEY_N_MOUSE_MAX_N)
+
+/* ޥܥκ */
+
+#define	KEY_N_MOUSE_MAX_N	(0\
+	+ KEY_N_MOUSE_CLICK_MAX_N \
+	+ KEY_N_MOUSE_D_CLICK_MAX_N \
+	+ KEY_N_MOUSE_P_CLICK_MAX_N \
+	+ KEY_N_MOUSE_PRESS_MAX_N \
+	+ KEY_N_MOUSE_RELEASE_MAX_N \
+	+ KEY_N_MOUSE_MOTION_MAX_N \
+	)
+
+/* ե󥯥󡦥󥹤λѤƤ륭κ */
+
+#define	KEY_N_MAX_N	(0\
+	+ KEY_N_FUNC_MAX_N \
+	+ KEY_N_MOUSE_MAX_N \
+	+ KEY_N_JOYSTICK_MAX_N \
+	)
+
 /***************************************************************
 * ɽСǡμ
 ***************************************************************/
