@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.152 2009/06/26 16:58:16 bowkenken Exp $
+* $Id: dun.c,v 1.158 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -469,6 +469,7 @@ void	reset_all( bool_t flg_appear )
 	garbage_collection_all_item();
 	reset_trap();
 	reset_mnstr();
+	reset_spell();
 	release_all_mbr();
 
 	clr_map_all_mbr();
@@ -1815,20 +1816,37 @@ door_t	*make_door_flg(
 	if( dy <= 0 )
 		return NULL;
 
-	/* ΰ֤ˤǤ˥ɥʤ return */
+	/* ΰ֤ˤǤ礭ɥʤ return */
 	for( i = 0; i < n; i++ ){
-		if( dun.door[i].x != bx )
+		if( bx < dun.door[i].x )
 			continue;
-		if( dun.door[i].y != by )
+		if( by < dun.door[i].y )
 			continue;
-		if( dun.door[i].dx != dx )
+		if( (dun.door[i].x + dun.door[i].dx) < (bx + dx) )
 			continue;
-		if( dun.door[i].dy != dy )
+		if( (dun.door[i].y + dun.door[i].dy) < (by + dy) )
 			continue;
 
 		return NULL;
 	}
 
+	/* ΰ֤ˤǤ˾ɥʤ */
+	for( i = 0; i < n; i++ ){
+		if( dun.door[i].x < bx )
+			continue;
+		if( dun.door[i].y < by )
+			continue;
+		if( (bx + dx) < (dun.door[i].x + dun.door[i].dx) )
+			continue;
+		if( (by + dy) < (dun.door[i].y + dun.door[i].dy) )
+			continue;
+
+		dun.door[i].x = MAP_DEL_X;
+		dun.door[i].y = MAP_DEL_Y;
+		dun.door[i].dx = 0;
+		dun.door[i].dy = 0;
+	}
+
 	dun.door[n].n = n;
 	dun.door[n].x = bx;
 	dun.door[n].y = by;
@@ -3548,13 +3566,27 @@ door_t	*get_door( long x, long y )
 	long	i;
 	door_t	*dr;
 
+	if( !clip_pos( x, y ) )
+		return NULL;
+
 	for( i = 0; i < dun.door_n; i++ ){
 		dr = &(dun.door[i]);
-		if( (dr->x <= x) && (x <= dr->x + dr->dx)
-				&& (dr->y <= y) && (y <= dr->y + dr->dy) ){
-			return dr;
-		}
+		if( x < dr->x )
+			continue;
+		if( x > dr->x + dr->dx - 1 )
+			continue;
+		if( y < dr->y )
+			continue;
+		if( y > dr->y + dr->dy - 1 )
+			continue;
+		if( dun.map.obj.mjr[y][x] != dr->mjr )
+			continue;
+		if( dun.map.obj.mnr[y][x] != dr->mnr )
+			continue;
+
+		return dr;
 	}
+
 	return NULL;
 }
 
@@ -4198,13 +4230,13 @@ bool_t	clip_draw_x( long n )
 
 	if( g_flg_cui ){
 		draw = get_map_draw_pos();
-		if( (draw->x <= n)
-				&& (n <= (draw->x + WIN_MAP_WIDTH - 1)) ){
+		if( (n <= (draw->x + (get_map_col() / 2) - 1))
+				&& (draw->x <= n) ){
 			return TRUE;
 		}
 	}
 	if( g_flg_gui ){
-		if( call_pcg_dun_clip_win_x( n ) )
+		if( call_pcg_dun_clip_win_x( n, FALSE ) )
 			return TRUE;
 	}
 
@@ -4226,13 +4258,13 @@ bool_t	clip_draw_y( long n )
 
 	if( g_flg_cui ){
 		draw = get_map_draw_pos();
-		if( (draw->y <= n)
-				&& (n <= (draw->y + WIN_MAP_WIDTH - 1)) ){
+		if( (n <= (draw->y + get_map_row() - 1))
+				&& (draw->y <= n) ){
 			return TRUE;
 		}
 	}
 	if( g_flg_gui ){
-		if( call_pcg_dun_clip_win_y( n ) )
+		if( call_pcg_dun_clip_win_y( n, FALSE ) )
 			return TRUE;
 	}
 
