@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.166 2009/09/11 19:26:26 bowkenken Exp $
+* $Id: fight.c,v 1.170 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -365,45 +365,83 @@ bool_t	set_attack_mnstr_bash(
 
 /***************************************************************
 * ֹ
-* chr_t *chr : ¦饯
-* chr_t *chr2 : ɸ¦饯
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
 * attack_t *dflt_attack : ǥեȤιǡ
 * return : ?
 ***************************************************************/
 
-bool_t	fight_throw( chr_t *chr1, chr_t *chr2, attack_t *dflt_attack )
+bool_t	fight_throw( chr_t *o_p, chr_t *d_p, attack_t *dflt_attack )
 {
-	item_t	*eq;
 	attack_t	attack;
 	long	d;
 
-	if( chr1 == NULL )
+	if( o_p == NULL )
 		return FALSE;
 
-	if( is_mbr( chr1 ) ){
-		eq = get_mbr_item_asgn_equip( chr1 );
-		if( eq == NULL )
-			return FALSE;
+	/* check stick */
+	if( chk_fight_zap( o_p ) )
+		return fight_zap( o_p );
 
-		/* check stick */
-
-		if( eq[EQUIP_KIND_BOW].kind == ITEM_KIND_STICK ){
-			if( !zap_stick( chr1, &(eq[EQUIP_KIND_BOW]) ) )
-				clr_chr_trgt_act( chr1, FALSE );
-			return TRUE;
-		}
-	}
-
-	d = get_trgt_range( chr1 );
+	d = get_trgt_range( o_p );
 
 	if( dflt_attack == NULL ){
-		if( !set_attack_chr_throw( chr1, &attack, d, FALSE ) )
+		if( !set_attack_chr_throw( o_p, &attack, d, FALSE ) )
 			return FALSE;
 	} else {
 		attack = *dflt_attack;
 	}
 
-	return fight( chr1, chr2, &attack, d );
+	return fight( o_p, d_p, &attack, d );
+}
+
+/***************************************************************
+* Ƥ뤫å
+* mbr_t *mbr : С
+* return : Ƥ뤫?
+***************************************************************/
+
+bool_t	chk_fight_zap( mbr_t *mbr )
+{
+	item_t	*eq;
+
+	if( mbr == NULL )
+		return FALSE;
+	if( !is_mbr( mbr ) )
+		return FALSE;
+
+	eq = get_mbr_item_asgn_equip( mbr );
+	if( eq == NULL )
+		return FALSE;
+	if( eq[EQUIP_KIND_ARW].kind != ITEM_KIND_NULL )
+		return FALSE;
+	if( eq[EQUIP_KIND_BOW].kind != ITEM_KIND_STICK )
+		return FALSE;
+
+	return TRUE;
+}
+
+/***************************************************************
+* ǹ
+* mbr_t *mbr : С
+* return : ?
+***************************************************************/
+
+bool_t	fight_zap( mbr_t *mbr )
+{
+	item_t	*eq;
+
+	if( !is_mbr( mbr ) )
+		return FALSE;
+
+	eq = get_mbr_item_asgn_equip( mbr );
+	if( eq == NULL )
+		return FALSE;
+
+	if( !zap_stick( mbr, &(eq[EQUIP_KIND_BOW]) ) )
+		clr_chr_trgt_act( mbr, FALSE );
+
+	return TRUE;
 }
 
 /***************************************************************
@@ -671,6 +709,9 @@ attack_t	*get_attack_ave(
 		ave.hit += ls[i].hit * n;
 		ave.crtcl += ls[i].crtcl * n;
 		ave.dam += ls[i].dam * n;
+
+		ave.flg_throw = ls[i].flg_throw;
+		ave.flg_monk = ls[i].flg_monk;
 	}
 
 	if( sum <= 0 )
@@ -862,11 +903,9 @@ bool_t	fight(
 	for( i = 0; i < attack_n; i++ ){
 		if( fight_x_1( o_p, d_p, attack, range, FALSE ) ){
 			hit_n++;
-		} else {
-			if( fight_two_sword_fencing( o_p, d_p,
-					attack, range ) ){
-				hit_n++;
-			}
+		} else if( fight_two_sword_fencing( o_p, d_p,
+				attack, range ) ){
+			hit_n++;
 		}
 	}
 
@@ -1058,28 +1097,31 @@ long	calc_two_sword_fencing_n( chr_t *o_p, const attack_t *attack )
 	abl_kind_t	abl;
 	long	lev;
 	rate_t	rate;
+	long	min_n;
+
+	min_n = SKILL_TWO_SWORD_FENCING_MIN_N;
 
 	if( o_p == NULL )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 	if( !is_mbr( o_p ) )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 	if( attack == NULL )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 	if( attack->flg_throw )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 	if( attack->flg_monk )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 
 	if( !chk_ena_skill( o_p, SKILL_KIND_TWO_SWORD_FENCING ) )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 
 	eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
 	if( eq == NULL )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 	if( eq[EQUIP_KIND_WIELDING].kind != ITEM_KIND_WPN )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 	if( eq[EQUIP_KIND_SHIELD].kind != ITEM_KIND_WPN )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 
 	abl = (abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_TWO_SWORD_FENCING);
 	lev = get_lev( o_p, abl );
