@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.c,v 1.205 2009/02/17 00:56:59 bowkenken Exp $
+* $Id: gfile.c,v 1.211 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -47,6 +47,8 @@ void	init_game_file( void )
 {
 	char	*home, *s;
 
+	g_rc_lex_num_mode = 0;
+
 	g_game_data_save_n = 0;
 	g_randm_seed_save = get_randm_seed();
 
@@ -631,19 +633,37 @@ rc_token_t	rc_lex( FILE *fp, rc_union_t *u, bool_t flg_err_exit )
 		case '\"':
 			return( rc_lex_str( fp, u, flg_err_exit ) );
 		case '0':
-			c = rc_lex_getc( fp, TRUE, flg_err_exit );
-			if( ('0' <= c) && (c <= '7') ){
+			if( g_rc_lex_num_mode == 8 ){
 				rc_lex_ungetc( fp, c );
 				n = rc_lex_oct( fp,
 						TOKEN_MAX_LEN,
 						flg_err_exit );
-			} else if( (c == 'x') || (c == 'X') ){
+			} else if( g_rc_lex_num_mode == 10 ){
+				rc_lex_ungetc( fp, c );
+				n = rc_lex_dec( fp,
+						TOKEN_MAX_LEN,
+						flg_err_exit );
+			} else if( g_rc_lex_num_mode == 16 ){
+				rc_lex_ungetc( fp, c );
 				n = rc_lex_hex_dec( fp,
 						TOKEN_MAX_LEN,
 						flg_err_exit );
 			} else {
-				rc_lex_ungetc( fp, c );
-				n = 0;
+				c = rc_lex_getc( fp, TRUE, flg_err_exit );
+
+				if( ('0' <= c) && (c <= '7') ){
+					rc_lex_ungetc( fp, c );
+					n = rc_lex_oct( fp,
+							TOKEN_MAX_LEN,
+							flg_err_exit );
+				} else if( (c == 'x') || (c == 'X') ){
+					n = rc_lex_hex_dec( fp,
+							TOKEN_MAX_LEN,
+							flg_err_exit );
+				} else {
+					rc_lex_ungetc( fp, c );
+					n = 0;
+				}
 			}
 
 			if( u != NULL )
@@ -658,10 +678,22 @@ rc_token_t	rc_lex( FILE *fp, rc_union_t *u, bool_t flg_err_exit )
 		case '7':
 		case '8':
 		case '9':
-			rc_lex_ungetc( fp, c );
-			n = rc_lex_dec( fp,
-					TOKEN_MAX_LEN,
-					flg_err_exit );
+			if( g_rc_lex_num_mode == 8 ){
+				rc_lex_ungetc( fp, c );
+				n = rc_lex_oct( fp,
+						TOKEN_MAX_LEN,
+						flg_err_exit );
+			} else if( g_rc_lex_num_mode == 16 ){
+				rc_lex_ungetc( fp, c );
+				n = rc_lex_hex_dec( fp,
+						TOKEN_MAX_LEN,
+						flg_err_exit );
+			} else {
+				rc_lex_ungetc( fp, c );
+				n = rc_lex_dec( fp,
+						TOKEN_MAX_LEN,
+						flg_err_exit );
+			}
 
 			if( u != NULL )
 				u->n = n;
@@ -1022,6 +1054,48 @@ bool_t	rename_back_up_file( char *fname )
 	return FALSE;
 }
 
+/***************************************************************
+* ǥå饢󥫡Ѵ
+* long idx : ǥå
+* return : 󥫡
+***************************************************************/
+
+square_dir_t	trans_idx_to_square_dir( long idx )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_square_dir_trans_tab )
+			/ sizeof( g_square_dir_trans_tab[0] );
+
+	if( idx < 0 )
+		return SQUARE_DIR_NORTH;
+	if( idx >= max_idx )
+		return SQUARE_DIR_NORTH;
+
+	return( g_square_dir_trans_tab[idx] );
+}
+
+/***************************************************************
+* 󥫡饤ǥåѴ
+* chr_kind_t k : 󥫡
+* return : ǥå
+***************************************************************/
+
+long	trans_square_dir_to_idx( square_dir_t dir )
+{
+	long	max_idx;
+	long	i;
+
+	max_idx = sizeof( g_square_dir_trans_tab )
+			/ sizeof( g_square_dir_trans_tab[0] );
+
+	for( i = 0; i < max_idx; i++ )
+		if( g_square_dir_trans_tab[i] == dir )
+			return i;
+
+	return 0;
+}
+
 /***************************************************************
 * ǥå饭饯μѴ
 * long idx : ǥå
@@ -3475,6 +3549,17 @@ long	load_crypt_c( FILE *fp )
 {
 	long	c;
 
+	c = load_crypt_c_sub( fp );
+	if( c == '\n' )
+		inc_rc_lex_line();
+
+	return c;
+}
+
+long	load_crypt_c_sub( FILE *fp )
+{
+	long	c;
+
 	if( feof( fp ) )
 		return EOF;
 
@@ -3497,10 +3582,6 @@ long	load_crypt_c( FILE *fp )
 			}
 			c = '\n';
 		}
-		if( c == '\n' ){
-			inc_rc_lex_line();
-			c = '\n';
-		}
 	} else {
 		c = randm_crypt( c );
 		g_crypt_sum += (char)c;
@@ -3531,3 +3612,11 @@ void	un_load_crypt_c( FILE *fp, long c )
 {
 	g_un_c = c;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_gfile_c( void )
+{
+}
