@@ -178,6 +178,15 @@ char	*cb_menu_func_set_reg_macro( menu_t **pp, menu_t **dflt );
 long	get_func_draw_n( long n );
 char	*cb_menu_gui( menu_t **pp, menu_t **dflt );
 char	*cb_menu_move_crsr_dflt( menu_t **pp, menu_t **dflt );
+char	*cb_menu_sound( menu_t **pp, menu_t **dflt );
+char	*cb_menu_music_volume( menu_t **pp, menu_t **dflt );
+char	*cb_menu_sound_volume( menu_t **pp, menu_t **dflt );
+rate_t	get_music_volume_rate( void );
+rate_t	set_music_volume_rate( rate_t rate );
+rate_t	get_sound_volume_rate( void );
+rate_t	set_sound_volume_rate( rate_t rate );
+char	*cb_menu_mute_sound( menu_t **pp, menu_t **dflt );
+void	mute_sound( bool_t flg );
 char	*cb_menu_replay_music( menu_t **pp, menu_t **dflt );
 char	*cb_menu_joystick_sel_n_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_joystick_sel_kind_init( menu_t **pp, menu_t **dflt );
