@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.c,v 1.227 2009/08/21 10:33:54 bowkenken Exp $
+* $Id: menu.c,v 1.231 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #define	MENU_C
@@ -46,11 +46,11 @@ static long	g_sel_menu_accel_key;
 static bool_t	g_flg_move_crsr_dflt;
 check_memory_def( check_memory_menu_c_g_nest_flg_executing_menu )
 
-#define	MENU_CURRENT_PASS_MAX_N	8
-static long	g_menu_current_pass_n;
-static char	g_menu_current_pass
-	[MENU_CURRENT_PASS_MAX_N][MENU_PATH_MAX_LEN + 1];
-check_memory_def( check_memory_menu_c_g_menu_current_pass_n )
+#define	MENU_CURRENT_PATH_MAX_N	8
+static long	g_menu_current_path_n;
+static char	g_menu_current_path
+	[MENU_CURRENT_PATH_MAX_N][MENU_PATH_MAX_LEN + 1];
+check_memory_def( check_memory_menu_c_g_menu_current_path_n )
 
 static ask_t	g_sel_ask;
 check_memory_def( check_memory_menu_c_g_sel_ask )
@@ -347,7 +347,7 @@ void	init_var_menu( void )
 	g_nest_flg_executing_menu = make_nest_flg();
 	g_sel_menu_accel_key = '\0';
 
-	clr_menu_current_pass();
+	clr_menu_current_path();
 
 	set_flg_space_select( FALSE );
 	set_flg_menu_dflt( TRUE );
@@ -834,21 +834,21 @@ const char	*get_msg_menu_mouse( long n )
 
 	if( n < KEY_N_FUNC_MAX_N ){
 		sn_printf( buf, MENU_MSG_MAX_BYTE,
-				MSG_MENU_FUNC_KEY, n );
+				MSG_MENU_FUNC_KEY, n + 1 );
 		return buf;
 	}
 	n -= KEY_N_FUNC_MAX_N;
 
 	if( n < KEY_N_MOUSE_CLICK_MAX_N ){
 		sn_printf( buf, MENU_MSG_MAX_BYTE,
-				MSG_MENU_MOUSE_CLICK, n );
+				MSG_MENU_MOUSE_CLICK, n + 1 );
 		return buf;
 	}
 	n -= KEY_N_MOUSE_CLICK_MAX_N;
 
 	if( n < KEY_N_MOUSE_D_CLICK_MAX_N ){
 		sn_printf( buf, MENU_MSG_MAX_BYTE,
-				MSG_MENU_MOUSE_D_CLICK, n );
+				MSG_MENU_MOUSE_D_CLICK, n + 1 );
 		return buf;
 	}
 	n -= KEY_N_MOUSE_D_CLICK_MAX_N;
@@ -857,11 +857,11 @@ const char	*get_msg_menu_mouse( long n )
 		switch( n ){
 		case 0:
 			sn_printf( buf, MENU_MSG_MAX_BYTE,
-					MSG_MENU_MOUSE_P_CLICK, 0, 2 );
+					MSG_MENU_MOUSE_P_CLICK, 1, 3 );
 			return buf;
 		case 1:
 			sn_printf( buf, MENU_MSG_MAX_BYTE,
-					MSG_MENU_MOUSE_P_CLICK, 2, 0 );
+					MSG_MENU_MOUSE_P_CLICK, 3, 1 );
 			return buf;
 		}
 		return str_null;
@@ -870,14 +870,14 @@ const char	*get_msg_menu_mouse( long n )
 
 	if( n < KEY_N_MOUSE_PRESS_MAX_N ){
 		sn_printf( buf, MENU_MSG_MAX_BYTE,
-				MSG_MENU_MOUSE_PRESS, n );
+				MSG_MENU_MOUSE_PRESS, n + 1 );
 		return buf;
 	}
 	n -= KEY_N_MOUSE_PRESS_MAX_N;
 
 	if( n < KEY_N_MOUSE_RELEASE_MAX_N ){
 		sn_printf( buf, MENU_MSG_MAX_BYTE,
-				MSG_MENU_MOUSE_RELEASE, n );
+				MSG_MENU_MOUSE_RELEASE, n + 1 );
 		return buf;
 	}
 	n -= KEY_N_MOUSE_RELEASE_MAX_N;
@@ -1216,7 +1216,7 @@ char	*exec_menu_sub( menu_t *p, menu_t *dflt, char *str_goto )
 
 			clr_msg();
 
-			push_menu_current_pass( pre_p->path );
+			push_menu_current_path( pre_p->path );
 
 			if( str_goto == NULL ){
 				ret = exec_menu( p, dflt, str_goto );
@@ -1227,7 +1227,7 @@ char	*exec_menu_sub( menu_t *p, menu_t *dflt, char *str_goto )
 				ret = exec_menu( p, dflt, &(str_goto[len]) );
 			}
 
-			pop_menu_current_pass();
+			pop_menu_current_path();
 
 			return ret;
 		}
@@ -1287,9 +1287,9 @@ char	*exec_menu_sub( menu_t *p, menu_t *dflt, char *str_goto )
 * ˥塼θߤΥѥ򥯥ꥢ
 ***************************************************************/
 
-void	clr_menu_current_pass( void )
+void	clr_menu_current_path( void )
 {
-	g_menu_current_pass_n = 0;
+	g_menu_current_path_n = 0;
 }
 
 /***************************************************************
@@ -1297,18 +1297,18 @@ void	clr_menu_current_pass( void )
 * return : ߤΥѥ
 ***************************************************************/
 
-const char	*get_menu_current_pass( void )
+const char	*get_menu_current_path( void )
 {
-	static char	pass[MENU_PATH_MAX_LEN + 1];
+	static char	path[MENU_PATH_MAX_LEN + 1];
 	long	i;
 
-	pass[0] = '\0';
-	for( i = 0; i < g_menu_current_pass_n; i++ ){
-		str_max_n_cat( pass, g_menu_current_pass[i],
+	path[0] = '\0';
+	for( i = 0; i < g_menu_current_path_n; i++ ){
+		str_max_n_cat( path, g_menu_current_path[i],
 				MENU_PATH_MAX_LEN );
 	}
 
-	return pass;
+	return path;
 }
 
 /***************************************************************
@@ -1316,30 +1316,30 @@ const char	*get_menu_current_pass( void )
 * const char *path : ɲäѥ
 ***************************************************************/
 
-void	push_menu_current_pass( const char *path )
+void	push_menu_current_path( const char *path )
 {
-	if( g_menu_current_pass_n < 0 ){
-		g_menu_current_pass_n++;
+	if( g_menu_current_path_n < 0 ){
+		g_menu_current_path_n++;
 		return;
 	}
-	if( g_menu_current_pass_n >= MENU_CURRENT_PASS_MAX_N ){
-		g_menu_current_pass_n++;
+	if( g_menu_current_path_n >= MENU_CURRENT_PATH_MAX_N ){
+		g_menu_current_path_n++;
 		return;
 	}
 
-	str_nz_cpy( g_menu_current_pass[g_menu_current_pass_n],
+	str_nz_cpy( g_menu_current_path[g_menu_current_path_n],
 			path, MENU_PATH_MAX_LEN );
 
-	g_menu_current_pass_n++;
+	g_menu_current_path_n++;
 }
 
 /***************************************************************
 * ˥塼θߤΥѥ᤹
 ***************************************************************/
 
-void	pop_menu_current_pass( void )
+void	pop_menu_current_path( void )
 {
-	g_menu_current_pass_n--;
+	g_menu_current_path_n--;
 }
 
 /***************************************************************
@@ -1760,7 +1760,7 @@ menu_t	*sel_menu_sub( menu_t *p, menu_t *dflt )
 	long	n, sel_n, max_n;
 	bool_t	flg_head;
 	bool_t	flg_set_dflt;
-	char	str_pass[MENU_PATH_MAX_LEN + 1];
+	char	str_path[MENU_PATH_MAX_LEN + 1];
 	int	i;
 
 	if( p == NULL )
@@ -1784,11 +1784,6 @@ menu_t	*sel_menu_sub( menu_t *p, menu_t *dflt )
 			page_max_n++;
 		}
 
-		if( tmp_p == dflt ){
-			page_sel_n = page_max_n - 1;
-			sel_n = n;
-		}
-
 		if( strcmp( tmp_p->kind, "<Title>" ) == 0 ){
 			;
 		} else if( strcmp( tmp_p->kind, "<Separator>" ) == 0 ){
@@ -1797,6 +1792,11 @@ menu_t	*sel_menu_sub( menu_t *p, menu_t *dflt )
 			n = 0;
 			flg_head = TRUE;
 		} else {
+			if( tmp_p == dflt ){
+				page_sel_n = page_max_n - 1;
+				sel_n = n;
+			}
+
 			n++;
 		}
 	}
@@ -1939,17 +1939,17 @@ menu_t	*sel_menu_sub( menu_t *p, menu_t *dflt )
 					1 );
 			break;
 		case MENU_COMMAND_KEY_CHAR:
-			str_nz_cpy( str_pass, MENU_COMMAND_KEY_STR,
+			str_nz_cpy( str_path, MENU_COMMAND_KEY_STR,
 					MENU_PATH_MAX_LEN );
-			str_max_n_cat( str_pass, get_menu_current_pass(),
+			str_max_n_cat( str_path, get_menu_current_path(),
 					MENU_PATH_MAX_LEN );
-			str_max_n_cat( str_pass, data.ls[sel_n]->path,
+			str_max_n_cat( str_path, data.ls[sel_n]->path,
 					MENU_PATH_MAX_LEN );
-			str_max_n_cat( str_pass, "\n",
+			str_max_n_cat( str_path, "\n",
 					MENU_PATH_MAX_LEN );
 
 			set_reg_macro( TRUE );
-			reg_macro_str( str_pass );
+			reg_macro_str( str_path );
 			set_reg_macro( FALSE );
 			break;
 		}
@@ -2022,6 +2022,8 @@ long	set_ls_menu(
 					MENU_MSG_MAX_BYTE );
 
 		if( page_n == page_sel_n ){
+			const char	*fmt = MSG_ERR_MENU_ACCEL_KEY;
+
 			if( strcmp( tmp_p->kind, "<Title>" ) == 0 ){
 				data->ttl = tmp_p->msg;
 			} else if( strcmp( tmp_p->kind,
@@ -2040,7 +2042,7 @@ long	set_ls_menu(
 						break;
 
 					print_msg( FLG_MSG_ERR,
-							MSG_ERR_MENU_ACCEL_KEY,
+							fmt,
 							tmp_p->accel_key,
 							tmp_p->msg );
 				} while( 0 );
@@ -2314,7 +2316,7 @@ long	chk_key( bool_t flg_clr_key_buf, bool_t flg_chk_menu )
 		/* ˥塼ɽ */
 		if( flg_chk_menu ){
 			move_all_mbr_trgt();
-			clr_menu_current_pass();
+			clr_menu_current_path();
 			exec_menu( get_ls_menu_main(),
 					get_menu_dflt_main(), NULL );
 			wipe_menu();
@@ -2763,8 +2765,8 @@ void	check_memory_menu_c( void )
 {
 	check_memory( check_memory_menu_c_g_nest_flg_executing_menu,
 			"menu.c: g_nest_flg_executing_menu" );
-	check_memory( check_memory_menu_c_g_menu_current_pass_n,
-			"menu.c: g_menu_current_pass_n" );
+	check_memory( check_memory_menu_c_g_menu_current_path_n,
+			"menu.c: g_menu_current_path_n" );
 	check_memory( check_memory_menu_c_g_sel_ask,
 			"menu.c: g_sel_ask" );
 	check_memory( check_memory_menu_c_menu_kind_ls,
