@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.52 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: mmenu.c,v 1.59 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -39,32 +39,39 @@
 
 static pos_t	g_crsr, g_pre_crsr;
 static pos_t	g_sub_crsr, g_pre_sub_crsr;
+check_memory_def( check_memory_mmenu_c_g_crsr )
 
 static menu_t	*g_menu_dflt_main;
+check_memory_def( check_memory_mmenu_c_g_menu_dflt_main )
 
 static chr_t	*g_sub_sel_mbr;
 static abl_kind_t	g_sel_abl;
 static race_t	g_sel_race;
 static sex_t	g_sel_sex;
 static long	g_sel_class_n;
+check_memory_def( check_memory_mmenu_c_g_sub_sel_mbr )
 
 static bool_t	g_flg_no_save;
 static long	g_sel_save_load_n;
+check_memory_def( check_memory_mmenu_c_g_flg_no_save )
 
 static trgt_kind_t	g_sel_obj_trgt_kind;
 static chr_kind_t	g_dist_chr_kind;
 static dist_t	g_sel_dist;
 static act_kind_t	g_sel_act_kind;
+check_memory_def( check_memory_mmenu_c_g_sel_obj_trgt_kind )
 
 static long	g_sel_mbr_n;
 static item_t	*g_sel_item;
 static equip_kind_t	g_sel_equip_kind;
 static bool_t	g_flg_equip_self;
+check_memory_def( check_memory_mmenu_c_g_sel_mbr_n )
 
 static mbr_t	*g_mark_sel_mbr;
 static item_t	*g_mark_sel_item;
 static door_t	*g_mark_sel_door;
 static trap_t	*g_mark_sel_trap;
+check_memory_def( check_memory_mmenu_c_g_mark_sel_mbr )
 
 typedef struct {
 	equip_kind_t	kind;
@@ -86,6 +93,7 @@ static ls_equip_msg_t	ls_equip_msg[] = {
 	{ EQUIP_KIND_ABOUT_BODY, N_MSG_MENU_SEL_EQUIP_ABOUT_BODY },
 	{ EQUIP_KIND_LIGHT_SOURCE, N_MSG_MENU_SEL_EQUIP_LIGHT_SOURCE },
 };
+check_memory_def( check_memory_mmenu_c_ls_equip_msg )
 
 /**/
 
@@ -94,6 +102,7 @@ static ls_equip_msg_t	ls_equip_msg[] = {
 /**/
 
 static long static_cb_menu_item__pre_sel_mbr_n;
+check_memory_def( check_memory_mmenu_c_pre_sel_mbr_n )
 
 /**/
 
@@ -1056,8 +1065,6 @@ bool_t	menu_mark_mnstr( pos_t pos1, pos_t pos2 )
 	mnstr = get_mnstr( pos2.x, pos2.y );
 	if( mbr == NULL )
 		return FALSE;
-	if( mnstr == NULL )
-		return FALSE;
 
 	if( !set_chr_act( mbr, g_sel_act_kind, NULL, NULL, 0, 0 ) )
 		return FALSE;
@@ -1066,7 +1073,10 @@ bool_t	menu_mark_mnstr( pos_t pos1, pos_t pos2 )
 	str_nz_cpy( mbr->act.dflt_msg_mnstr, mbr->act.msg,
 			ACT_MSG_MAX_BYTE );
 
-	mark_mnstr( mbr, mnstr, g_sel_dist );
+	if( mnstr == NULL )
+		mark_mnstr_null( mbr, pos2.x, pos2.y, g_sel_dist );
+	else
+		mark_mnstr( mbr, mnstr, g_sel_dist );
 
 	draw_mbr_stat( mbr );
 
@@ -1657,6 +1667,9 @@ char	*cb_menu_item_sel_init( menu_t **pp, menu_t **dflt )
 	clr_flg_menu( *pp, "alias", FLG_MENU_HIDDEN );
 	clr_flg_menu( *pp, "check", FLG_MENU_HIDDEN );
 
+	if( chk_have_chest( pty->mbr[g_sel_mbr_n] ) )
+		clr_flg_menu( *pp, "put in chest", FLG_MENU_HIDDEN );
+
 	switch( g_sel_item->kind ){
 	case ITEM_KIND_NULL:
 	case ITEM_KIND_MAX_N:
@@ -1687,6 +1700,8 @@ char	*cb_menu_item_sel_init( menu_t **pp, menu_t **dflt )
 		clr_flg_menu( *pp, "eat", FLG_MENU_HIDDEN );
 		break;
 	case ITEM_KIND_CHEST:
+		set_flg_menu( *pp, "put in chest", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "list chest", FLG_MENU_HIDDEN );
 		break;
 	case ITEM_KIND_TOBACCO:
 		clr_flg_menu( *pp, "smoke", FLG_MENU_HIDDEN );
@@ -1989,6 +2004,208 @@ char	*cb_menu_item_receive( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_item_put_in_chest( menu_t **pp, menu_t **dflt )
+{
+	long	n;
+	char	*res;
+	party_t	*pty = get_party();
+	mbr_t	*mbr;
+	item_t	*tmp;
+
+	if( g_sel_mbr_n <= -1 )
+		return STR_MENU_ERR;
+	mbr = pty->mbr[g_sel_mbr_n];
+
+	if( g_sel_item == NULL )
+		return STR_MENU_ERR;
+
+	n = g_sel_item->n;
+	res = exec_menu_sel_num( &n, 1, g_sel_item->n );
+	if( res != NULL )
+		return res;
+
+	tmp = alloc_item();
+	if( tmp == NULL )
+		return STR_MENU_ERR;
+
+	copy_item( tmp, g_sel_item );
+	inc_item( tmp, -(tmp->n - n) );
+
+	if( !put_item_in_chest_quick( mbr, tmp ) ){
+		del_item( tmp );
+		return STR_MENU_CANCEL;
+	}
+
+	inc_item( g_sel_item, -n );
+
+	return "/item";
+}
+
+/**/
+
+char	*cb_menu_item_ls_chest( menu_t **pp, menu_t **dflt )
+{
+	party_t	*pty = get_party();
+	menu_t	*ls;
+	mbr_t	*mbr;
+	item_t	*chest, *head, *p;
+	long	j, k;
+
+	if( g_sel_item == NULL )
+		return STR_MENU_ERR;
+	if( g_sel_item->kind != ITEM_KIND_CHEST )
+		return STR_MENU_ERR;
+	if( g_sel_mbr_n <= -1 )
+		return STR_MENU_ERR;
+	if( g_sel_mbr_n >= MBR_MAX_N )
+		return STR_MENU_ERR;
+
+	mbr = pty->mbr[g_sel_mbr_n];
+	chest = g_sel_item;
+
+	if( chest->dat.chest.trap != NULL ){
+		curs_attrset_chr( mbr, -1, FALSE );
+		print_msg( FLG_NULL, MSG_ERR_MENU_LS_CHEST_TRAP,
+				chest->name );
+		curs_attrset_dflt();
+
+		return STR_MENU_CANCEL;
+	}
+
+	if( chk_flg_or( mbr->stat,
+			FLG_STAT_NOT_EXIST
+			| FLG_STAT_DEAD
+			| FLG_STAT_STONE
+			| FLG_STAT_PARALYZE
+			| FLG_STAT_SLEEP
+			| FLG_STAT_FAINT ) ){
+		print_msg( FLG_NULL, MSG_ERR_MENU_SEL_ITEM, mbr->name );
+		return STR_MENU_CANCEL;
+	}
+
+	ls = ls_menu_chest;
+	k = 0;
+
+	str_nz_cpy( ls[k].path, "/chest", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	str_nz_cpy( ls[k].path, "/chest/--", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	str_nz_cpy( ls[k].msg, MSG_MENU_ITEM_LS_CHEST, MENU_MSG_MAX_BYTE );
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	head = chest->dat.chest.contents;
+	p = head->next;
+	for( j = 0; j < CHEST_HOLD_MAX_N; j++, p = p->next ){
+		if( p == head )
+			break;
+
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/chest/%ld", j );
+		str_nz_cpy( ls[k].kind, "<OpenWinItem>",
+				MENU_KIND_MAX_LEN );
+		ls[k].accel_key = (char)('A' + j);
+		ls[k].short_key[0] = '\0';
+		ls[k].n_msg = N_MSG_NULL;
+		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE, "%s", p->name );
+		ls[k].call_back = cb_menu_chest_sel;
+		ls[k].arg = (void *)p;
+		ls[k].flg = FLG_NULL;
+		k++;
+	}
+
+	if( j <= 0 ){
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/chest/%ld", j );
+		str_nz_cpy( ls[k].kind, "<Item>",
+				MENU_KIND_MAX_LEN );
+		ls[k].accel_key = (char)('A' + j);
+		ls[k].short_key[0] = '\0';
+		ls[k].n_msg = N_MSG_ITEM_NO_SEL;
+		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE, MSG_ITEM_NO_SEL );
+		ls[k].call_back = cb_menu_chest_sel;
+		ls[k].arg = NULL;
+		ls[k].flg = FLG_NULL;
+		k++;
+	}
+
+	ls[k].path[0] = '\0';
+
+	while( 1 ){
+		char	*res;
+
+		res = exec_menu( ls, NULL, NULL );
+		if( res == NULL )
+			continue;
+		if( strcmp( res, STR_MENU_CANCEL ) == 0 )
+			return "/item";
+
+		return res;
+	}
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_chest_sel( menu_t **pp, menu_t **dflt )
+{
+	party_t	*pty = get_party();
+	mbr_t	*mbr;
+	item_t	*item, *tmp;
+	long	n;
+	char	*res;
+
+	if( g_sel_mbr_n <= -1 )
+		return STR_MENU_ERR;
+	if( g_sel_mbr_n >= MBR_MAX_N )
+		return STR_MENU_ERR;
+
+	mbr = pty->mbr[g_sel_mbr_n];
+	item = (item_t *)((*pp)->arg);
+	if( mbr == NULL )
+		return STR_MENU_ERR;
+	if( item == NULL )
+		return STR_MENU_CANCEL;
+
+	n = item->n;
+	res = exec_menu_sel_num( &n, 1, item->n );
+	if( res != NULL )
+		return res;
+
+	tmp = alloc_item();
+	if( tmp == NULL )
+		return STR_MENU_ERR;
+
+	copy_item( tmp, item );
+	inc_item( tmp, -(tmp->n - n) );
+
+	if( !give_mbr_item( mbr, tmp, FALSE ) ){
+		del_item( tmp );
+		return STR_MENU_CANCEL;
+	}
+
+	inc_item( item, -n );
+
+	return "/item sel/list chest";
+}
+
+/**/
+
 char	*cb_menu_item_drop( menu_t **pp, menu_t **dflt )
 {
 	long	n;
@@ -2560,43 +2777,56 @@ void	menu_move_square( void )
 
 char	*cb_menu_fight( menu_t **pp, menu_t **dflt )
 {
+	bool_t	flg_loop;
 	pos_t	pos1, pos2;
 	char	*str;
 	char	c;
 
 	set_menu_dflt_main( *pp );
 
-	pos1 = g_crsr;
-	c = get_chr_mjr_crsr();
-	if( c != FACE_MJR_MBR ){
-		mbr_t	*mbr;
+	flg_loop = FALSE;
+	do {
+		pos1 = g_crsr;
+		c = get_chr_mjr_crsr();
+		if( c != FACE_MJR_MBR ){
+			mbr_t	*mbr;
 
-		str = exec_menu_sel_mbr( &mbr, NULL, FALSE, FALSE );
-		if( str != NULL )
-			return str;
-		if( mbr == NULL )
-			return STR_MENU_ERR;
+			flg_loop = TRUE;
 
-		g_sel_mbr_n = mbr->mbr_n;
-		pos1.x = mbr->x;
-		pos1.y = mbr->y;
-	}
+			str = exec_menu_sel_mbr( &mbr, NULL, FALSE, FALSE );
+			if( str != NULL )
+				return str;
+			if( mbr == NULL )
+				return STR_MENU_ERR;
 
-	str = exec_menu_point_crsr();
-	if( str != NULL )
-		return str;
+			g_sel_mbr_n = mbr->mbr_n;
+			pos1.x = mbr->x;
+			pos1.y = mbr->y;
+		}
 
-	pos2 = g_crsr;
-	c = get_chr_mjr_crsr();
+		str = exec_menu_point_crsr();
+		if( str == NULL ){
+			flg_loop = FALSE;
+		} else {
+			if( strcmp( str, STR_MENU_CANCEL ) == 0 )
+				continue;
+			else
+				return str;
+		}
 
-	if( c == FACE_MJR_MBR ){
-		if( !menu_mark_mbr( pos1, pos2 ) )
-			return STR_MENU_ERR;
-	} else {
-		if( !menu_mark_mnstr( pos1, pos2 ) )
-			return STR_MENU_ERR;
-	}
+		pos2 = g_crsr;
+		c = get_chr_mjr_crsr();
 
+		if( c == FACE_MJR_MBR ){
+			if( !menu_mark_mbr( pos1, pos2 ) )
+				return STR_MENU_ERR;
+		} else {
+			if( !menu_mark_mnstr( pos1, pos2 ) )
+				return STR_MENU_ERR;
+		}
+	} while( flg_loop );
+
+	*pp = NULL;
 	return NULL;
 }
 
@@ -2970,16 +3200,16 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 		j = 0;
 		if( (p == NULL) || (p == item) ){
 			sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
-					"/identify item/unknown %c",
+					"/identify item/no sel %c",
 					(char)('A' + i) );
 			str_nz_cpy( ls[k].kind, "<Item>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = (char)('A' + j);
 			ls[k].short_key[0] = '\0';
-			ls[k].n_msg = N_MSG_ITEM_UNKNOWN;
-			str_nz_cpy( ls[k].msg, MSG_ITEM_UNKNOWN,
+			ls[k].n_msg = N_MSG_ITEM_NO_SEL;
+			str_nz_cpy( ls[k].msg, MSG_ITEM_NO_SEL,
 					MENU_MSG_MAX_BYTE );
-			ls[k].call_back = cb_menu_identify_item_unknown;
+			ls[k].call_back = cb_menu_identify_item_no_sel;
 			ls[k].arg = (void *)NULL;
 			ls[k].flg = FLG_NULL;
 			k++;
@@ -3046,7 +3276,7 @@ char	*cb_menu_identify_item( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_identify_item_unknown( menu_t **pp, menu_t **dflt )
+char	*cb_menu_identify_item_no_sel( menu_t **pp, menu_t **dflt )
 {
 	return STR_MENU_CANCEL;
 }
@@ -3224,6 +3454,9 @@ void	update_crsr( void )
 	draw_crsr();
 	draw_sub_crsr();
 
+	/* ơС˥ҥȤɽ */
+	call_gui_map_print_stat_bar_hint();
+
 	reset_crsr();
 }
 
@@ -3269,5 +3502,30 @@ void	set_sel_mbr_n( long n )
 	g_sel_mbr_n = n;
 }
 
-/**/
+/***************************************************************
+* ꡼å
+***************************************************************/
 
+void	check_memory_mmenu_c( void )
+{
+	check_memory( check_memory_mmenu_c_g_crsr,
+			"mmenu.c: g_crsr" );
+	check_memory( check_memory_mmenu_c_g_menu_dflt_main,
+			"mmenu.c: g_menu_dflt_main" );
+	check_memory( check_memory_mmenu_c_g_sub_sel_mbr,
+			"mmenu.c: g_sub_sel_mbr" );
+	check_memory( check_memory_mmenu_c_g_flg_no_save,
+			"mmenu.c: g_flg_no_save" );
+	check_memory( check_memory_mmenu_c_g_sel_obj_trgt_kind,
+			"mmenu.c: g_sel_obj_trgt_kind" );
+	check_memory( check_memory_mmenu_c_g_sel_mbr_n,
+			"mmenu.c: g_sel_mbr_n" );
+	check_memory( check_memory_mmenu_c_g_mark_sel_mbr,
+			"mmenu.c: g_mark_sel_mbr" );
+	check_memory( check_memory_mmenu_c_ls_equip_msg,
+			"mmenu.c: ls_equip_msg" );
+	check_memory( check_memory_mmenu_c_pre_sel_mbr_n,
+			"mmenu.c: pre_sel_mbr_n" );
+}
+
+/**/
