@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.225 2009/06/06 08:04:22 bowkenken Exp $
+* $Id: mnstr.c,v 1.232 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -57,19 +57,26 @@
 /*  */
 #define	GROUP_RATE_BASE	50
 
+/* 󥹥֤ޤϼʬ˲ʸ򾧤 HP κΨ */
+#define	MNSTR_SPELL_FRIEND_HP_RATE	70
+
 /***************************************************************
 * 󥹥Υǡ
 ***************************************************************/
 
 /* ס */
 static mnstr_t	mnstr_buf[MNSTR_MAX_N];
+check_memory_def( check_memory_mnstr_c_mnstr_buf )
 /* ƺ */
 static mnstr_t	mnstr_used;
+check_memory_def( check_memory_mnstr_c_mnstr_used )
 /* ̤ */
 static mnstr_t	mnstr_free;
+check_memory_def( check_memory_mnstr_c_mnstr_free )
 
 /* 饹ܥ */
 static mnstr_t	*g_last_boss[LAST_BOSS_KIND_MAX_N];
+check_memory_def( check_memory_mnstr_c_g_last_boss )
 
 /***************************************************************
 * 󥹥Υǡơ֥
@@ -826,6 +833,24 @@ void	act_phase_all_mnstr( void )
 	}
 }
 
+/***************************************************************
+* ƤΥ󥹥ԥե¹
+***************************************************************/
+
+void	dismissal_phase_all_mnstr( void )
+{
+	mnstr_t	*head, *p, *pp;
+
+	head = &mnstr_used;
+	for( p = head->next->next; p != NULL; p = p->next ){
+		pp = p->prev;
+		if( pp == head )
+			break;
+
+		dismissal_phase_chr( pp );
+	}
+}
+
 /***************************************************************
 * 󥹥ιư¹ԽΥޤǰưĴ٤
 * mnstr_t *p : 󥹥
@@ -1145,6 +1170,7 @@ mbr_t	*mnstr_mark_mbr_adjoin( mnstr_t *p )
 bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 {
 	chr_t	*trgt;
+	act_kind_t	act_kind;
 	attack_t	*ls;
 	ratio_t	sum_bash, sum_throw, sum_spell, n;
 
@@ -1158,6 +1184,8 @@ bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 			&& (p->trgt.kind != TRGT_KIND_MNSTR) ){
 		return FALSE;
 	}
+	if( p->trgt.p == NULL )
+		return FALSE;
 
 	trgt = (chr_t *)(p->trgt.p);
 	ls = p->mnstr_tab->attack;
@@ -1172,16 +1200,27 @@ bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 	n = randm( sum_bash + sum_throw + sum_spell );
 
 	if( n < sum_bash ){
-		set_chr_act( p, ACT_KIND_MBR_FIGHT,
-				trgt, NULL, 0, 0 );
+		if( is_mbr( trgt ) )
+			act_kind = ACT_KIND_MBR_FIGHT;
+		else
+			act_kind = ACT_KIND_MNSTR_FIGHT;
+
+		set_chr_act( p, act_kind, trgt, NULL, 0, 0 );
 	} else if( n < sum_bash + sum_throw ){
-		set_chr_act( p, ACT_KIND_MBR_THROW,
-				trgt, NULL, 0, 0 );
+		if( is_mbr( trgt ) )
+			act_kind = ACT_KIND_MBR_THROW;
+		else
+			act_kind = ACT_KIND_MNSTR_THROW;
+
+		set_chr_act( p, act_kind, trgt, NULL, 0, 0 );
 	} else {
+		bool_t	flg_cast;
 		attack_t	*atk;
 		long	d;
 		chr_t	*friend_chr;
 
+		flg_cast = TRUE;
+
 		d = max_l( labs( p->x - trgt->x ), labs( p->y - trgt->y ) );
 		atk = get_attack( FALSE, ls, d,
 				FALSE, FALSE, FALSE, TRUE );
@@ -1191,33 +1230,40 @@ bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 		if( atk->kind == ATTACK_KIND_SPELL_SELF )
 			friend_chr = p;
 		else if( atk->kind == ATTACK_KIND_SPELL_FRIEND )
-			friend_chr = get_mnstr_randm( p->x, p->y );
+			friend_chr = get_mnstr_friend( p, p->x, p->y );
 		else
 			friend_chr = NULL;
 
-		if( friend_chr != NULL ){
+		if( friend_chr == NULL ){
+			if( !chk_find_chr( p, trgt ) )
+				flg_cast = FALSE;
+		} else {
 			rate_t	rate;
 
-			trgt = friend_chr;
 			rate = friend_chr->abl.hp.n * _100_PERCENT
 					/ friend_chr->abl.hp.max;
-			if( rate < 70 ){
+
+			if( (rate <= MNSTR_SPELL_FRIEND_HP_RATE)
+					&& chk_find_chr( p, friend_chr ) ){
+				trgt = friend_chr;
 				mark_mnstr( p, friend_chr, DIST_FAR );
 			} else {
-				set_chr_act( p, ACT_KIND_MBR_FIGHT,
-						trgt, NULL, 0, 0 );
-				return TRUE;
+				flg_cast = FALSE;
 			}
 		}
 
-		if( chk_find_chr( p, trgt ) ){
+		if( flg_cast ){
 			set_chr_act( p, ACT_KIND_SPELL,
 					get_spell_tab( atk->spell ),
 					MSG( atk->spell_fmt ),
 					atk->extent, 0 );
 		} else {
-			set_chr_act( p, ACT_KIND_MBR_FIGHT,
-					trgt, NULL, 0, 0 );
+			if( is_mbr( trgt ) )
+				act_kind = ACT_KIND_MBR_FIGHT;
+			else
+				act_kind = ACT_KIND_MNSTR_FIGHT;
+
+			set_chr_act( p, act_kind, trgt, NULL, 0, 0 );
 		}
 	}
 
@@ -2351,12 +2397,12 @@ void	ins_ls_mnstr( mnstr_t *ls, mnstr_t *p )
 /***************************************************************
 * 󥹥ݤηиͤ׻
 * 󥹥Υ٥Υ롼פθ
-* mnstr_t *p : 󥹥
+* mnstr_kind_t mnstr_kind : 󥹥μ
 * long dun_lev : 󥸥γ
 * return : и
 ***************************************************************/
 
-long	calc_mnstr_exp( mnstr_t *p, long dun_lev )
+long	calc_mnstr_exp( mnstr_kind_t mnstr_kind, long dun_lev )
 {
 	long	dun_lev_max, dun_lev_mod;
 	long	lev_mul;
@@ -2370,8 +2416,8 @@ long	calc_mnstr_exp( mnstr_t *p, long dun_lev )
 	if( lev_mul < 0 )
 		lev_mul = 0;
 
-	exp_max = calc_mnstr_exp_sub( p, dun_lev_max );
-	exp_mod = calc_mnstr_exp_sub( p, dun_lev_mod );
+	exp_max = calc_mnstr_exp_sub( mnstr_kind, dun_lev_max );
+	exp_mod = calc_mnstr_exp_sub( mnstr_kind, dun_lev_mod );
 	exp = (exp_max * lev_mul) + exp_mod;
 
 	return exp;
@@ -2379,20 +2425,20 @@ long	calc_mnstr_exp( mnstr_t *p, long dun_lev )
 
 /***************************************************************
 * 󥹥ݤηиͤ׻
-* mnstr_t *p : 󥹥
+* mnstr_kind_t mnstr_kind : 󥹥μ
 * long dun_lev : 󥸥γ
 * return : и
 ***************************************************************/
 
-long	calc_mnstr_exp_sub( mnstr_t *p, long dun_lev )
+long	calc_mnstr_exp_sub( mnstr_kind_t mnstr_kind, long dun_lev )
 {
+	mnstr_tab_t	*tab;
 	long	lev;
 	long	exp;
 
-	if( p == NULL )
-		return 1;
-	if( p->mnstr_tab == NULL )
-		return 1;
+	tab = NULL;
+	if( mnstr_kind != MNSTR_KIND_NULL )
+		tab = get_mnstr_tab( mnstr_kind, dun_lev );
 
 	/* µܤγؤ׻ */
 
@@ -2407,12 +2453,15 @@ long	calc_mnstr_exp_sub( mnstr_t *p, long dun_lev )
 
 	/*  */
 
-	exp += exp * p->mnstr_tab->exp / _100_PERCENT;
+	if( tab != NULL )
+		exp += exp * tab->exp / _100_PERCENT;
 
 	/* ο */
 
-	exp *= calc_mnstr_group_rate( p->mnstr_tab->group );
-	exp /= _100_PERCENT;
+	if( tab != NULL ){
+		exp *= calc_mnstr_group_rate( tab->group );
+		exp /= _100_PERCENT;
+	}
 
 	/**/
 
@@ -2531,6 +2580,9 @@ mnstr_t	*get_mnstr( long x, long y )
 	if( !clip_pos( x, y ) )
 		return NULL;
 
+	if( dun->map.chr.mjr[y][x] == FACE_MJR_NULL )
+		return NULL;
+
 	p = dun->map.chr_p[y][x];
 	if( (p != NULL) && (p->kind == CHR_KIND_MNSTR) )
 		return p;
@@ -2775,7 +2827,7 @@ mnstr_t	*get_mnstr_mp_max( long x, long y )
 }
 
 /***************************************************************
-* 1  MP ¿󥹥򸡺
+* 1 (HP/MP)(¿/ʤ)󥹥򸡺
 * long x : X ɸ
 * long y : Y ɸ
 * return : 󥹥
@@ -2818,16 +2870,16 @@ mnstr_t	*get_mnstr_hp_mp_min_max(
 		else
 			tmp_n = pp->abl.mp.n;
 
-		if( (min_max >= +1) && (tmp_n > min_max_n) ){
-			min_max_n = tmp_n;
-			n = 0;
-		} else if( (min_max <= -1) && (tmp_n < min_max_n) ){
-			min_max_n = tmp_n;
-			n = 0;
-		} else if( tmp_n == min_max_n ){
+		if( tmp_n == min_max_n ){
 			n++;
 			if( randm( n ) != 0 )
 				continue;
+		} else if( (min_max >= +1) && (tmp_n > min_max_n) ){
+			min_max_n = tmp_n;
+			n = 1;
+		} else if( (min_max <= -1) && (tmp_n < min_max_n) ){
+			min_max_n = tmp_n;
+			n = 1;
 		} else {
 			continue;
 		}
@@ -2984,6 +3036,25 @@ mnstr_t	*get_mnstr_randm2( long x, long y )
 	return NULL;
 }
 
+/***************************************************************
+* 󥹥֤˸
+* mnstr_t *p : 󥹥
+* long x : X ɸ
+* long y : Y ɸ
+* return : 󥹥
+***************************************************************/
+
+chr_t	*get_mnstr_friend( mnstr_t *p, long x, long y )
+{
+	if( p == NULL )
+		return get_mnstr_hp_min( x, y );
+
+	if( p->attitude == ATTITUDE_ENEMY )
+		return get_mnstr_hp_min( x, y );
+
+	return get_mbr_hp_min();
+}
+
 /***************************************************************
 * 󥹥δʸ򸡺
 * char mjr : ᥸㡼δʸ
@@ -3034,3 +3105,18 @@ mnstr_t	*get_mnstr_used( void )
 	return &mnstr_used;
 }
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_mnstr_c( void )
+{
+	check_memory( check_memory_mnstr_c_mnstr_buf,
+			"mnstr.c: mnstr_buf" );
+	check_memory( check_memory_mnstr_c_mnstr_used,
+			"mnstr.c: mnstr_used" );
+	check_memory( check_memory_mnstr_c_mnstr_free,
+			"mnstr.c: mnstr_free" );
+	check_memory( check_memory_mnstr_c_g_last_boss,
+			"mnstr.c: g_last_boss" );
+}
