@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.235 2009/06/06 08:04:22 bowkenken Exp $
+* $Id: party.c,v 1.244 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -62,8 +62,11 @@
 ***************************************************************/
 
 static mbr_t	*ls_mbr[LS_MBR_MAX_N + 1];
+check_memory_def( check_memory_party_c_ls_mbr )
 static mbr_t	ls_mbr_buf[LS_MBR_MAX_N + 1];
+check_memory_def( check_memory_party_c_ls_mbr_buf )
 static party_t	party;
+check_memory_def( check_memory_party_c_party )
 
 static long	abl_init[MAIN_RACE_MAX_N][ABL_KIND_MAX_N] = {
 
@@ -118,6 +121,7 @@ static long	abl_init[MAIN_RACE_MAX_N][ABL_KIND_MAX_N] = {
 		0, 0, 0, 0,
 	},
 };
+check_memory_def( check_memory_party_c_abl_init )
 
 static rate_t	resi_init[MAIN_RACE_MAX_N][RESI_KIND_MAX_N] = {
 	/* KNOC,SLAS,STIN,HEAT,COLD,MIND,ACID,ELEC,POIS, */
@@ -132,6 +136,7 @@ static rate_t	resi_init[MAIN_RACE_MAX_N][RESI_KIND_MAX_N] = {
 /* MAIN_RACE_VIVID */
 	{    90,  90,  90, 100, 100, 200, 100, 100, 100 },
 };
+check_memory_def( check_memory_party_c_resi_init )
 
 static stomach_t	ave_stomach[MAIN_RACE_MAX_N] = {
 #if	0
@@ -149,6 +154,7 @@ typedef struct {
 	{ 100, 200, 25, 0, 70, 30 },	/* MAIN_RACE_DWARF, */
 	{ 100, 180, 25, 0, 70, 30 },	/* MAIN_RACE_VIVID, */
 };
+check_memory_def( check_memory_party_c_ave_stomach )
 
 /* class */
 
@@ -636,6 +642,11 @@ void	init_party_debug( void )
 	init_mbr_item( ls_mbr[i], ITEM_KIND_WPN, &sub_kind,
 			TRUE, FALSE, TRUE );
 
+	i = 6;
+	sub_kind.wpn = WPN_KIND_BOOMERANG;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_WPN, &sub_kind,
+			TRUE, FALSE, TRUE );
+
 	/* armor */
 
 	i = 1;
@@ -730,6 +741,11 @@ void	init_party_debug( void )
 	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
 			TRUE, FALSE, FALSE );
 
+	i = 2;
+	sub_kind.scroll = SCROLL_KIND_BOOMERANG;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			TRUE, FALSE, FALSE );
+
 	i = 4;
 	sub_kind.scroll = SCROLL_KIND_TELEPORT;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
@@ -874,21 +890,7 @@ void	init_party_debug( void )
 	init_mbr_item( ls_mbr[i], ITEM_KIND_ARMOR, &sub_kind,
 			TRUE, FALSE, TRUE );
 
-	i = 0;
-	sub_kind.ring = RING_KIND_STRENGTH;
-	sub_kind.amulet = AMULET_KIND_NULL;
-	sub_kind.necklace = NECKLACE_KIND_NULL;
-	init_mbr_item( ls_mbr[i], ITEM_KIND_ACCE, &sub_kind,
-			TRUE, FALSE, TRUE );
-
-	i = 0;
-	sub_kind.ring = RING_KIND_NULL;
-	sub_kind.amulet = AMULET_KIND_NULL;
-	sub_kind.necklace = NECKLACE_KIND_CURSE_HEAT;
-	init_mbr_item( ls_mbr[i], ITEM_KIND_ACCE, &sub_kind,
-			FALSE, TRUE, FALSE );
-
-	i = 0;
+	i = 1;
 	sub_kind.ring = RING_KIND_DRAIN_HP;
 	sub_kind.amulet = AMULET_KIND_NULL;
 	sub_kind.necklace = NECKLACE_KIND_NULL;
@@ -1969,12 +1971,15 @@ void	act_phase_party( void )
 	switch( party.act.kind ){
 	default:
 		break;
-	case ACT_KIND_RECALL:
-		chk_recall();
-		break;
 	case ACT_KIND_SHOP:
 		enter_shop();
 		break;
+	case ACT_KIND_TELEPORT_PARTY:
+		chk_teleport_party();
+		break;
+	case ACT_KIND_RECALL:
+		chk_recall();
+		break;
 	}
 }
 
@@ -2730,23 +2735,31 @@ long	get_mbr_race_exp( mbr_t *mbr, long exp, abl_kind_t abl )
 
 void	remove_mbr( mbr_t *mbr )
 {
-	long	i;
 	long	mbr_n, ls_mbr_n;
-	mbr_t	*tmp_mbr, *p;
+	mbr_t	*p;
 
 	if( mbr == NULL )
 		return;
 
+	/* ꥹȤ򤺤餹 */
+
+	menu_bar_arrange( mbr, +1 );
+	mbr = get_ls_mbr_tail();
+	if( mbr == NULL )
+		return;
+
+	/**/
+
 	mbr_n = mbr->mbr_n;
 	ls_mbr_n = mbr->ls_mbr_n;
 
-	/**/
+	/* ƥǡ */
 
 	remove_cast_tab( ls_mbr_n );
 	remove_auto_mark_mbr( ls_mbr_n );
 	remove_mbr_del_item( ls_mbr_n );
 
-	/* ls_mbr */
+	/* mark */
 
 	p = ls_mbr[ls_mbr_n];
 	clr_map_chr( p );
@@ -2763,17 +2776,10 @@ void	remove_mbr( mbr_t *mbr )
 	if( mbr_n != MBR_N_NOT_JOIN )
 		party.mbr[mbr_n] = ls_mbr[LS_MBR_NULL];
 
-	/* ꥹȤ򤺤餹 */
+	/* ls_mbr */
 
-	tmp_mbr = ls_mbr[ls_mbr_n];
-	for( i = ls_mbr_n; i < LS_MBR_MAX_N - 1; i++ ){
-		ls_mbr[i] = ls_mbr[i + 1];
-		ls_mbr[i]->ls_mbr_n--;
-	}
-	ls_mbr[i] = tmp_mbr;
-
-	ls_mbr[i]->mbr_n = MBR_N_NOT_JOIN;
-	ls_mbr[i]->stat |= FLG_STAT_NOT_EXIST;
+	ls_mbr[ls_mbr_n]->mbr_n = MBR_N_NOT_JOIN;
+	ls_mbr[ls_mbr_n]->stat |= FLG_STAT_NOT_EXIST;
 }
 
 /**/
@@ -3125,15 +3131,7 @@ mbr_t	*get_mbr_hp_mp_min_max( bool_t flg_hp, long min_max )
 			tmp_n = p->abl.mp.n;
 		}
 
-		if( (min_max >= +1) && (tmp_rate > min_max_rate) ){
-			min_max_rate = tmp_rate;
-			min_max_n = tmp_n;
-			n = 1;
-		} else if( (min_max <= -1) && (tmp_rate < min_max_rate) ){
-			min_max_rate = tmp_rate;
-			min_max_n = tmp_n;
-			n = 1;
-		} else if( tmp_rate == min_max_rate ){
+		if( tmp_rate == min_max_rate ){
 			if( (min_max >= +1) && (tmp_n > min_max_n) ){
 				min_max_rate = tmp_rate;
 				min_max_n = tmp_n;
@@ -3153,6 +3151,14 @@ mbr_t	*get_mbr_hp_mp_min_max( bool_t flg_hp, long min_max )
 			} else {
 				continue;
 			}
+		} else if( (min_max >= +1) && (tmp_rate > min_max_rate) ){
+			min_max_rate = tmp_rate;
+			min_max_n = tmp_n;
+			n = 1;
+		} else if( (min_max <= -1) && (tmp_rate < min_max_rate) ){
+			min_max_rate = tmp_rate;
+			min_max_n = tmp_n;
+			n = 1;
 		} else {
 			continue;
 		}
@@ -3317,6 +3323,24 @@ mbr_t	**get_ls_mbr( void )
 
 /**/
 
+mbr_t	*get_ls_mbr_tail( void )
+{
+	long	i;
+
+	for( i = LS_MBR_MAX_N - 1; i >= 0; i-- ){
+		if( ls_mbr[i] == NULL )
+			continue;
+		if( chk_flg( ls_mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
+			continue;
+
+		return ls_mbr[i];
+	}
+
+	return NULL;
+}
+
+/**/
+
 party_t	*get_party( void )
 {
 	return &party;
@@ -3333,6 +3357,12 @@ long	get_mbr_n( long x, long y )
 
 	dun = get_dun();
 
+	if( !clip_pos( x, y ) )
+		return MBR_N_NOT_JOIN;
+
+	if( dun->map.chr.mjr[y][x] == FACE_MJR_NULL )
+		return MBR_N_NOT_JOIN;
+
 	p = dun->map.chr_p[y][x];
 	if( (p != NULL) && is_mbr( p ) )
 		return( p->mbr_n );
@@ -3626,3 +3656,22 @@ void	unset_square_pos( void )
 
 /**/
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_party_c( void )
+{
+	check_memory( check_memory_party_c_ls_mbr,
+			"party.c: ls_mbr" );
+	check_memory( check_memory_party_c_ls_mbr_buf,
+			"party.c: ls_mbr_buf" );
+	check_memory( check_memory_party_c_party,
+			"party.c: party" );
+	check_memory( check_memory_party_c_abl_init,
+			"party.c: abl_init" );
+	check_memory( check_memory_party_c_resi_init,
+			"party.c: resi_init" );
+	check_memory( check_memory_party_c_ave_stomach,
+			"party.c: ave_stomach" );
+}
