@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-tab.h,v 1.21 2009/08/08 21:02:29 bowkenken Exp $
+* $Id: spell-tab.h,v 1.24 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_TAB_H
@@ -52,6 +52,26 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
+/* ʸϿ */
+	{
+		"/spell/reg spell",
+		"<Item>",
+		ACCEL_KEY_REG_SPELL,
+		"",
+		N_MSG_NULL, "",
+		cb_menu_reg_spell, NULL,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/reg spell remark",
+		"<OpenWinItem>",
+		ACCEL_KEY_REG_SPELL_REMARK,
+		"",
+		N_MSG_NULL, "",
+		cb_menu_reg_spell_remark, NULL,
+		FLG_NULL,
+	},
 /* [ˡ] */
 	{
 		"/spell/MAG",
@@ -196,7 +216,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/MAG/no_learn misc",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -326,7 +346,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/MAG/no_learn detect",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -456,7 +476,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/MAG/no_learn change status",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -585,7 +605,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/SOR/no_learn attack",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -675,7 +695,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/SOR/no_learn defense",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -805,7 +825,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/SOR/no_learn weaken status",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -905,7 +925,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/ENC/no_learn strengthen ability",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -955,7 +975,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/ENC/no_learn strengthen misc",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1045,7 +1065,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/ENC/no_learn weaken ability",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1115,7 +1135,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/ENC/no_learn weaken misc",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1212,6 +1232,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/SUM/summon_random",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_RANDOM, "",
+		cb_menu_spell, (void *)SPELL_KIND_SUMMON_RANDOM,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/SUM/create_undead",
 		"<Branch>",
@@ -1235,7 +1265,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/SUM/no_learn summon",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1375,7 +1405,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/PRI/no_learn cure",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1515,7 +1545,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/PRI/no_learn cure status",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1625,7 +1655,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/PRI/no_learn resist",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1715,7 +1745,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/PRI/no_learn holy",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1815,7 +1845,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/SHA/no_learn weak elemental",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -1955,7 +1985,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/SHA/no_learn summon elemental",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -2015,7 +2045,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/BAR/no_learn cure",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -2105,7 +2135,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/BAR/no_learn strengthen ability",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -2195,7 +2225,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/BAR/no_learn weaken ability",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -2335,7 +2365,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/BAR/no_learn resist status",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -2425,7 +2455,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/NIN/no_learn disaster",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
@@ -2505,7 +2535,7 @@ menu_t	ls_menu_spell[] = {
 	{
 		"/spell/NIN/no_learn misc",
 		"<Item>",
-		'Z',
+		ACCEL_KEY_NO_LEARN,
 		"",
 		N_MSG_SPELL_NO_LEARN, "",
 		cb_menu_spell_no_learn, NULL,
