@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu-tab.h,v 1.27 2009/01/30 03:09:08 bowkenken Exp $
+* $Id: tmenu-tab.h,v 1.30 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TMENU_TAB_H
@@ -176,7 +176,7 @@ menu_t	ls_menu_magic_guild[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [ˡ] ¾ */
+/* [ˡ]  */
 	{
 		"/magic guild/MAG/title misc",
 		"<Title>",
@@ -276,27 +276,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_DISARM_TRAP,
 		FLG_NULL,
 	},
-
-	{
-		"/magic guild/MAG/dispel_magic",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_DISPEL_MAGIC, "",
-		cb_menu_magic_guild, (void *)SPELL_KIND_DISPEL_MAGIC,
-		FLG_NULL,
-	},
-
-	{
-		"/magic guild/MAG/mirror_image",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_MIRROR_IMAGE, "",
-		cb_menu_magic_guild, (void *)SPELL_KIND_MIRROR_IMAGE,
-		FLG_NULL,
-	},
-
+#if	0
 	{
 		"/magic guild/MAG/animate_objects",
 		"<Branch>",
@@ -306,7 +286,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_ANIMATE_OBJECTS,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/MAG/shelter",
 		"<Branch>",
@@ -386,7 +366,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_SEARCHING,
 		FLG_NULL,
 	},
-
+#if	0
 	{
 		"/magic guild/MAG/analyze_dweomer",
 		"<Branch>",
@@ -396,7 +376,8 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_ANALYZE_DWEOMER,
 		FLG_NULL,
 	},
-
+#endif
+#if	0
 	{
 		"/magic guild/MAG/detect_magic",
 		"<Branch>",
@@ -406,7 +387,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_DETECT_MAGIC,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/MAG/detect_item",
 		"<Branch>",
@@ -476,7 +457,7 @@ menu_t	ls_menu_magic_guild[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [ˡ] ƥѲ */
+/* [ˡ] Ѳ */
 	{
 		"/magic guild/MAG/title change status",
 		"<Title>",
@@ -496,7 +477,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_FLY,
 		FLG_NULL,
 	},
-
+#if	0
 	{
 		"/magic guild/MAG/feather_fall",
 		"<Branch>",
@@ -506,7 +487,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_FEATHER_FALL,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/MAG/vanish",
 		"<Branch>",
@@ -536,7 +517,58 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_PASSWALL,
 		FLG_NULL,
 	},
-/* [ˡ] üե饰Ѳ */
+#if	0
+	{
+		"/magic guild/MAG/dispel_magic",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_DISPEL_MAGIC, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_DISPEL_MAGIC,
+		FLG_NULL,
+	},
+#endif
+#if	0
+	{
+		"/magic guild/MAG/mirror_image",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_MIRROR_IMAGE, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_MIRROR_IMAGE,
+		FLG_NULL,
+	},
+#endif
+	{
+		"/magic guild/MAG/no_learn change status",
+		"<Item>",
+		'Z',
+		"",
+		N_MSG_SPELL_NO_LEARN, "",
+		cb_menu_magic_guild_no_learn, NULL,
+		FLG_NULL,
+	},
+
+	{
+		"/magic guild/MAG/--",
+		"<PageSeparator>",
+		'\0',
+		"",
+		N_MSG_NULL, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+/* [ˡ] üѲ */
+	{
+		"/magic guild/MAG/title change special",
+		"<Title>",
+		'\0',
+		"",
+		N_MSG_MAG_CHANGE_SPECIAL, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+
 	{
 		"/magic guild/MAG/polymorph_other",
 		"<Branch>",
@@ -546,7 +578,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_POLYMORPH_OTHER,
 		FLG_NULL,
 	},
-
+#if	0
 	{
 		"/magic guild/MAG/polymorph_self",
 		"<Branch>",
@@ -556,7 +588,8 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_POLYMORPH_SELF,
 		FLG_NULL,
 	},
-
+#endif
+#if	0
 	{
 		"/magic guild/MAG/stealth",
 		"<Branch>",
@@ -566,9 +599,9 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_STEALTH,
 		FLG_NULL,
 	},
-
+#endif
 	{
-		"/magic guild/MAG/no_learn change status",
+		"/magic guild/MAG/no_learn change special",
 		"<Item>",
 		'Z',
 		"",
@@ -687,6 +720,16 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/magic guild/SOR/word_of_destruction",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_WORD_OF_DESTRUCTION, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_WORD_OF_DESTRUCTION,
+		FLG_NULL,
+	},
+
 	{
 		"/magic guild/SOR/no_learn attack",
 		"<Item>",
@@ -736,7 +779,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_MAGE_ARMOR,
 		FLG_NULL,
 	},
-
+#if	0
 	{
 		"/magic guild/SOR/stoneskin",
 		"<Branch>",
@@ -746,7 +789,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_STONESKIN,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/SOR/iron_body",
 		"<Branch>",
@@ -756,7 +799,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_IRON_BODY,
 		FLG_NULL,
 	},
-
+#if	0
 	{
 		"/magic guild/SOR/spell_resistance",
 		"<Branch>",
@@ -766,7 +809,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_SPELL_RESISTANCE,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/SOR/counter_magic",
 		"<Branch>",
@@ -1046,7 +1089,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_POWER_UP_HP,
 		FLG_NULL,
 	},
-/* [ˡ]  */
+
 	{
 		"/magic guild/ENC/haste",
 		"<Branch>",
@@ -1186,7 +1229,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_ENERGY_DRAIN,
 		FLG_NULL,
 	},
-/* [ˡ]  */
+
 	{
 		"/magic guild/ENC/slow",
 		"<Branch>",
@@ -1196,7 +1239,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_SLOW,
 		FLG_NULL,
 	},
-
+#if	0
 	{
 		"/magic guild/ENC/hunger",
 		"<Branch>",
@@ -1206,7 +1249,8 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_HUNGER,
 		FLG_NULL,
 	},
-
+#endif
+#if	0
 	{
 		"/magic guild/ENC/cancellation",
 		"<Branch>",
@@ -1216,7 +1260,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_CANCELLATION,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/ENC/no_learn weaken misc",
 		"<Item>",
@@ -1316,7 +1360,18 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_SUMMON_BONE,
 		FLG_NULL,
 	},
-
+#if	0
+	{
+		"/magic guild/SUM/summon_random",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_RANDOM, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_SUMMON_RANDOM,
+		FLG_NULL,
+	},
+#endif
+#if	0
 	{
 		"/magic guild/SUM/create_undead",
 		"<Branch>",
@@ -1326,7 +1381,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_CREATE_UNDEAD,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/SUM/dismissal",
 		"<Branch>",
