@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.143 2009/05/14 00:26:39 bowkenken Exp $
+* $Id: tmenu.c,v 1.155 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -52,9 +52,7 @@
 		((LS_MBR_MAX_N + LS_MBR_MAX_N_PER_PAGE - 1)\
 		/ LS_MBR_MAX_N_PER_PAGE)
 
-#define	ORDER_MILK_MAX_LEV	100
-#define	ORDER_MILK_MIN_RATE	((rate_t)10)
-#define	ORDER_MILK_MAX_RATE	((rate_t)_100_PERCENT)
+#define	ORDER_MILK_HIGH_LEV	30
 
 /**/
 
@@ -63,21 +61,29 @@
 /**/
 
 static mbr_t	*g_sel_mbr, *g_sel_ls_mbr;
+check_memory_def( check_memory_tmenu_c_g_sel_mbr )
+
 static shop_n_t	g_shop_n;
 static deal_kind_t	g_deal_kind;
 static item_t	*g_sel_art;
 static long	g_sel_class_n;
+check_memory_def( check_memory_tmenu_c_g_shop_n )
+
 static item_t	*g_mbr_order[MBR_MAX_N];
+check_memory_def( check_memory_tmenu_c_g_mbr_order )
 
 static menu_t	*g_navi_dflt;
+check_memory_def( check_memory_tmenu_c_g_navi_dflt )
 
 /**/
 
 static edit_class_t	static_exec_edit_class__n;
 static edit_skill_t	static_exec_edit_skill__n;
+check_memory_def( check_memory_tmenu_c_static_exec_edit_class__n )
 
 skill_kind_t	g_sel_skill_kind;
 edit_skill_t	g_skill_slot_n;
+check_memory_def( check_memory_tmenu_c_g_sel_skill_kind  )
 
 /**/
 
@@ -140,10 +146,10 @@ char	*menu_shop_sel_mbr( shop_n_t shop_n, bool_t flg_pet )
 		flg_sel_dead = FALSE;
 
 	while( 1 ){
-		char	ttl[MENU_MSG_MAX_LEN + 1];
+		char	ttl[MENU_MSG_MAX_BYTE + 1];
 		char	*str_goto;
 
-		sn_printf( ttl, MENU_MSG_MAX_LEN, MSG_MENU_SHOP_SEL_MBR,
+		sn_printf( ttl, MENU_MSG_MAX_BYTE, MSG_MENU_SHOP_SEL_MBR,
 				get_shop_name( g_shop_n ) );
 
 		str_goto = exec_menu_sel_mbr(
@@ -207,14 +213,14 @@ char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 	for( p = *pp; p->path[0] != '\0'; p++ ){
 		long	tmp_len;
 
-		tmp_len = str_len_std( MSG( p->n_msg ) );
+		tmp_len = str_len_draw( MSG( p->n_msg ) );
 		max_len = max_l( max_len, tmp_len );
 	}
 
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_TEMPLE,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_TTL_MENU_TEMPLE,
 			get_shop_name( SHOP_N_TEMPLE ),
 			g_sel_mbr->name, fmt_gold( g_sel_mbr->gold ) );
 
@@ -223,7 +229,7 @@ char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 	if( p == NULL )
 		return STR_MENU_ERR;
 	len = get_pading_len( MSG( p->n_msg ), max_len );
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_FMT_MENU_TEMPLE,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_FMT_MENU_TEMPLE,
 			len, MSG( p->n_msg ), fmt_gold( price ) );
 
 	price = get_price_temple_cure_status( g_sel_mbr );
@@ -231,7 +237,7 @@ char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 	if( p == NULL )
 		return STR_MENU_ERR;
 	len = get_pading_len( MSG( p->n_msg ), max_len );
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_FMT_MENU_TEMPLE,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_FMT_MENU_TEMPLE,
 			len, MSG( p->n_msg ), fmt_gold( price ) );
 
 	price = get_price_temple_resurrection( g_sel_mbr );
@@ -239,7 +245,7 @@ char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 	if( p == NULL )
 		return STR_MENU_ERR;
 	len = get_pading_len( MSG( p->n_msg ), max_len );
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_FMT_MENU_TEMPLE,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_FMT_MENU_TEMPLE,
 			len, MSG( p->n_msg ), fmt_gold( price ) );
 
 	return NULL;
@@ -521,7 +527,7 @@ char	*menu_order_sel_mbr( void )
 	str_nz_cpy( p[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	p[k].accel_key = '\0';
 	p[k].short_key[0] = '\0';
-	str_nz_cpy( p[k].msg, MSG_TTL_MENU_ORDER, MENU_MSG_MAX_LEN );
+	str_nz_cpy( p[k].msg, MSG_TTL_MENU_ORDER, MENU_MSG_MAX_BYTE );
 	p[k].call_back = NULL;
 	p[k].arg = NULL;
 	p[k].flg = FLG_NULL;
@@ -549,7 +555,7 @@ char	*menu_order_sel_mbr( void )
 			name = MSG_MENU_ORDER_NULL;
 		else
 			name = g_mbr_order[i]->name;
-		sn_printf( p[k].msg, MENU_MSG_MAX_LEN,
+		sn_printf( p[k].msg, MENU_MSG_MAX_BYTE,
 				MSG_MENU_ORDER_MBR, mbr[i]->name, name );
 		p[k].call_back = cb_menu_order_sel;
 		p[k].arg = mbr[i];
@@ -566,7 +572,7 @@ char	*menu_order_sel_mbr( void )
 	str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	p[k].accel_key = 'Z';
 	p[k].short_key[0] = '\0';
-	str_nz_cpy( p[k].msg, MSG_MENU_ORDER_CHOSE, MENU_MSG_MAX_LEN );
+	str_nz_cpy( p[k].msg, MSG_MENU_ORDER_CHOSE, MENU_MSG_MAX_BYTE );
 	p[k].call_back = cb_menu_order_chose;
 	p[k].arg = NULL;
 	p[k].flg = FLG_NULL;
@@ -662,7 +668,7 @@ char	*cb_menu_order_chose( menu_t **pp, menu_t **dflt )
 			continue;
 
 		add_chr_gold( pty->mbr[i], -price );
-		call_game_sound_play( SOUND_KIND_SHOP_DRINK, 2 );
+		call_game_sound_play( SOUND_KIND_SHOP_BUY_DRINK, 2 );
 
 		tmp = alloc_item();
 		if( tmp == NULL )
@@ -698,8 +704,6 @@ char	*cb_menu_order_chose( menu_t **pp, menu_t **dflt )
 
 bool_t	chk_order_milk( mbr_t *mbr, shop_n_t shop_n, item_t *item )
 {
-	long	lev;
-	rate_t	rate;
 	sex_t	sex;
 
 	if( mbr == NULL )
@@ -714,21 +718,6 @@ bool_t	chk_order_milk( mbr_t *mbr, shop_n_t shop_n, item_t *item )
 	if( item->dat.potion.kind != POTION_KIND_MILK )
 		return FALSE;
 
-	/* ФΨ */
-
-	lev = get_specialist_lev( mbr );
-	rate = ORDER_MILK_MAX_LEV - lev;
-
-	if( rate < ORDER_MILK_MIN_RATE )
-		rate = ORDER_MILK_MIN_RATE;
-	if( rate > ORDER_MILK_MAX_RATE )
-		rate = ORDER_MILK_MAX_RATE;
-
-	/* Ф뤫 */
-
-	if( !rate_randm( rate ) )
-		return FALSE;
-
 	/* Ф */
 
 	if( rate_randm( (rate_t)50 ) )
@@ -740,6 +729,20 @@ bool_t	chk_order_milk( mbr_t *mbr, shop_n_t shop_n, item_t *item )
 			MSG_WORDS_ORDER_MILK_FEMALE,
 			MSG_WORDS_ORDER_MILK_MALE );
 
+	/* ٥Υå */
+
+	if( get_specialist_lev( mbr ) < ORDER_MILK_HIGH_LEV )
+		return TRUE;
+
+	if( rate_randm( (rate_t)50 ) )
+		sex = FEMALE;
+	else
+		sex = MALE;
+
+	print_words( MSG_NPC_NAME_BAR_CUSTOMER, sex,
+			MSG_WORDS_ORDER_MILK_HIGH_LEV_FEMALE,
+			MSG_WORDS_ORDER_MILK_HIGH_LEV_MALE );
+
 	return TRUE;
 }
 
@@ -815,7 +818,7 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
 			sn_printf( ls[k].msg,
-					MENU_MSG_MAX_LEN,
+					MENU_MSG_MAX_BYTE,
 					MSG_FMT_MENU_SHOP,
 					get_shop_name( shop_n ),
 					mbr->name, buy_sale,
@@ -830,7 +833,7 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 		ls_art[ls_art_n] = art;
 		ls_art_n++;
 
-		len = str_len_std( art->art_name );
+		len = str_len_draw( art->art_name );
 		max_len = max_l( len, max_len );
 
 		/* menu */
@@ -866,7 +869,7 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
 		sn_printf( ls[k].msg,
-				MENU_MSG_MAX_LEN,
+				MENU_MSG_MAX_BYTE,
 				MSG_FMT_MENU_SHOP,
 				get_shop_name( shop_n ),
 				mbr->name, buy_sale,
@@ -884,15 +887,22 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 	/* ̾ʤĤ */
 
 	for( i = 0, j = 0; i < k; i++ ){
+		gold_t	price;
+		const char	*str_gold;
+		long	len;
+
 		if( ls[i].arg == NULL )
 			continue;
 
+		price = get_price( g_shop_n, ls_art[j], g_deal_kind );
+		str_gold = fmt_gold( price );
+		len = get_pading_len( ls_art[j]->art_name, max_len );
+
 		sn_printf( ls[i].msg,
-				MENU_MSG_MAX_LEN,
+				MENU_MSG_MAX_BYTE,
 				MSG_FMT_ART_NAME,
-				max_len, ls_art[j]->art_name,
-				fmt_gold( get_price(
-				g_shop_n, ls_art[j], g_deal_kind ) ) );
+				len, ls_art[j]->art_name,
+				str_gold );
 		j++;
 	}
 
@@ -913,7 +923,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 	str_nz_cpy( ls[*k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	ls[*k].accel_key = 'T';
 	ls[*k].short_key[0] = '\0';
-	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_DATA, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_DATA, MENU_MSG_MAX_BYTE );
 	ls[*k].call_back = cb_menu_shop_data;
 	ls[*k].arg = NULL;
 	ls[*k].flg = FLG_NULL;
@@ -926,7 +936,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 	ls[*k].accel_key = 'U';
 	ls[*k].short_key[0] = '\0';
 	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_COLLECT_GOLD,
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	ls[*k].call_back = cb_menu_shop_collect_gold;
 	ls[*k].arg = NULL;
 	ls[*k].flg = FLG_NULL;
@@ -939,7 +949,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 	ls[*k].accel_key = 'V';
 	ls[*k].short_key[0] = '\0';
 	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_DIVIDE_GOLD,
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	ls[*k].call_back = cb_menu_shop_divide_gold;
 	ls[*k].arg = NULL;
 	ls[*k].flg = FLG_NULL;
@@ -952,7 +962,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 	ls[*k].accel_key = 'W';
 	ls[*k].short_key[0] = '\0';
 	str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_GIVE_GOLD,
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	ls[*k].call_back = cb_menu_shop_give_gold;
 	ls[*k].arg = NULL;
 	ls[*k].flg = FLG_NULL;
@@ -968,7 +978,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 			ls[*k].accel_key = 'X';
 			ls[*k].short_key[0] = '\0';
 			str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_SALE_EQUIP,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			ls[*k].call_back = cb_menu_shop_sale_equip;
 			ls[*k].arg = NULL;
 			ls[*k].flg = FLG_NULL;
@@ -984,7 +994,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 			ls[*k].accel_key = 'Y';
 			ls[*k].short_key[0] = '\0';
 			str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_SALE_ITEM,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			ls[*k].call_back = cb_menu_shop_sale_item;
 			ls[*k].arg = NULL;
 			ls[*k].flg = FLG_NULL;
@@ -1000,7 +1010,7 @@ void	set_ls_menu_shop( long *k, deal_kind_t deal_kind )
 			ls[*k].accel_key = 'Z';
 			ls[*k].short_key[0] = '\0';
 			str_nz_cpy( ls[*k].msg, MSG_MENU_SHOP_BUY,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			ls[*k].call_back = cb_menu_shop_buy;
 			ls[*k].arg = NULL;
 			ls[*k].flg = FLG_NULL;
@@ -1139,6 +1149,7 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 			return STR_MENU_CANCEL;
 
 		add_chr_gold( g_sel_mbr, -(price * deal_n / n) );
+		call_game_sound_play( SOUND_KIND_SHOP_BUY, 1 );
 
 	} else if( g_deal_kind == DEAL_KIND_SALE_ITEM ){
 		deal_n = menu_shop_sale_item( g_shop_n, g_sel_mbr, art );
@@ -1146,6 +1157,7 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 			return STR_MENU_CANCEL;
 
 		add_chr_gold( g_sel_mbr, +(price * deal_n / n) );
+		call_game_sound_play( SOUND_KIND_SHOP_SALE, 1 );
 
 	} else if( g_deal_kind == DEAL_KIND_SALE_EQUIP ){
 		deal_n = menu_shop_sale_equip( g_shop_n, g_sel_mbr, art );
@@ -1153,8 +1165,8 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 			return STR_MENU_CANCEL;
 
 		add_chr_gold( g_sel_mbr, +(price * deal_n / n) );
+		call_game_sound_play( SOUND_KIND_SHOP_SALE, 1 );
 	}
-	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
 
 	return "/shop";
 }
@@ -1668,7 +1680,7 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 		p[k].accel_key = '\0';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_TTL_MENU_BAR_FORM,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
@@ -1690,7 +1702,7 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 			p[k].accel_key = (char)('A' + j);
 			p[k].short_key[0] = '\0';
 			str_nz_cpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			p[k].call_back = cb_menu_bar_form_sub;
 			p[k].arg = ls_mbr[ls_mbr_n];
 			p[k].flg = FLG_NULL;
@@ -1764,7 +1776,7 @@ char	*cb_menu_bar_form_sub( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	str_nz_cpy( p->msg, g_sel_ls_mbr->name, MENU_MSG_MAX_LEN );
+	str_nz_cpy( p->msg, g_sel_ls_mbr->name, MENU_MSG_MAX_BYTE );
 
 	return NULL;
 }
@@ -1837,7 +1849,7 @@ char	*cb_menu_bar_join( menu_t **pp, menu_t **dflt )
 				MENU_KIND_MAX_LEN );
 		p[k].accel_key = (char)('A' + i);
 		p[k].short_key[0] = '\0';
-		sn_printf( p[k].msg, MENU_MSG_MAX_LEN, "%ld", i + 1 );
+		sn_printf( p[k].msg, MENU_MSG_MAX_BYTE, "%ld", i + 1 );
 		p[k].call_back = cb_menu_bar_join_sub;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -1980,7 +1992,7 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 		p[k].accel_key = '\0';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_TTL_MENU_BAR_EDIT_MBR,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
@@ -2003,7 +2015,7 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 			p[k].accel_key = (char)('A' + j);
 			p[k].short_key[0] = '\0';
 			str_nz_cpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			p[k].call_back = cb_menu_bar_edit_mbr_sub;
 			p[k].arg = ls_mbr[ls_mbr_n];
 			p[k].flg = FLG_NULL;
@@ -2071,7 +2083,7 @@ char	*cb_menu_bar_edit_mbr_sub( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_BAR_EDIT_MBR_SUB,
 			g_sel_ls_mbr->name );
 
@@ -2100,49 +2112,53 @@ char	*cb_menu_bar_data_edit( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_bar_arrange_up( menu_t **pp, menu_t **dflt )
 {
-	return cb_menu_bar_arrange_1( -1 );
+	menu_bar_arrange_1( g_sel_ls_mbr, -1 );
+	return "/bar/form/edit member/edit member";
 }
 
 /**/
 
 char	*cb_menu_bar_arrange_down( menu_t **pp, menu_t **dflt )
 {
-	return cb_menu_bar_arrange_1( +1 );
+	menu_bar_arrange_1( g_sel_ls_mbr, +1 );
+	return "/bar/form/edit member/edit member";
 }
 
 /**/
 
 char	*cb_menu_bar_arrange_top( menu_t **pp, menu_t **dflt )
 {
-	return cb_menu_bar_arrange( -1 );
+	menu_bar_arrange( g_sel_ls_mbr, -1 );
+	return "/bar/form/edit member/edit member";
 }
 
 /**/
 
 char	*cb_menu_bar_arrange_bottom( menu_t **pp, menu_t **dflt )
 {
-	return cb_menu_bar_arrange( +1 );
+	menu_bar_arrange( g_sel_ls_mbr, +1 );
+	return "/bar/form/edit member/edit member";
 }
 
 /**/
 
-char	*cb_menu_bar_arrange_1( long d )
+void	menu_bar_arrange_1( mbr_t *mbr, long d )
 {
 	long	trgt_ls_mbr_n;
 	mbr_t	**ls_mbr, *tmp_mbr;
 
-	if( g_sel_ls_mbr == NULL )
-		return STR_MENU_ERR;
+	if( mbr == NULL )
+		return;
 
 	ls_mbr = get_ls_mbr();
-	trgt_ls_mbr_n = g_sel_ls_mbr->ls_mbr_n;
+	trgt_ls_mbr_n = mbr->ls_mbr_n;
 	if( (trgt_ls_mbr_n + d) < 0 )
-		return "/bar/form/edit member/edit member";
+		return;
 	if( (trgt_ls_mbr_n + d) >= LS_MBR_MAX_N )
-		return "/bar/form/edit member/edit member";
+		return;
 	if( chk_flg( ls_mbr[trgt_ls_mbr_n + d]->stat,
 			FLG_STAT_NOT_EXIST ) ){
-		return "/bar/form/edit member/edit member";
+		return;
 	}
 
 	arrange_cast_tab_1( trgt_ls_mbr_n, d );
@@ -2161,29 +2177,28 @@ char	*cb_menu_bar_arrange_1( long d )
 	ls_mbr[trgt_ls_mbr_n + d]->ls_mbr_n = trgt_ls_mbr_n + d;
 
 	g_sel_ls_mbr = ls_mbr[0];
-	return "/bar/form/edit member/edit member";
 }
 
 /**/
 
-char	*cb_menu_bar_arrange( long d )
+void	menu_bar_arrange( mbr_t *mbr, long d )
 {
 	long	trgt_ls_mbr_n;
 	mbr_t	**ls_mbr, *tmp_mbr;
 	long	i;
 
-	if( g_sel_ls_mbr == NULL )
-		return STR_MENU_ERR;
+	if( mbr == NULL )
+		return;
 
 	ls_mbr = get_ls_mbr();
-	trgt_ls_mbr_n = g_sel_ls_mbr->ls_mbr_n;
+	trgt_ls_mbr_n = mbr->ls_mbr_n;
 
 	arrange_cast_tab( trgt_ls_mbr_n, d );
 	arrange_auto_mark_mbr( trgt_ls_mbr_n, d );
 	arrange_item( trgt_ls_mbr_n, d );
 	arrange_equip( trgt_ls_mbr_n, d );
 
-	tmp_mbr = g_sel_ls_mbr;
+	tmp_mbr = mbr;
 	if( d <= -1 ){
 		for( i = trgt_ls_mbr_n - 1; i >= 0; i-- ){
 			ls_mbr[i + 1] = ls_mbr[i];
@@ -2210,8 +2225,6 @@ char	*cb_menu_bar_arrange( long d )
 
 		g_sel_ls_mbr = ls_mbr[i - 1];
 	}
-
-	return "/bar/form/edit member/edit member";
 }
 
 /**/
@@ -2243,7 +2256,7 @@ bool_t	exec_menu_new_mbr( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[n], MSG_MENU_NEW_MBR,
 			'@', race, MALE, 0, n );
 
@@ -2311,7 +2324,7 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 		p[k].accel_key = '\0';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_TTL_MENU_BAR_REMOVE_MBR,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
@@ -2334,7 +2347,7 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 			p[k].accel_key = (char)('A' + j);
 			p[k].short_key[0] = '\0';
 			str_nz_cpy( p[k].msg, ls_mbr[ls_mbr_n]->name,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			p[k].call_back = cb_menu_bar_remove_mbr_sub;
 			p[k].arg = ls_mbr[ls_mbr_n];
 			p[k].flg = FLG_NULL;
@@ -2571,7 +2584,7 @@ char	*cb_menu_bar_new_class( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	}
 
-	str_nz_cpy( p[n].name, MSG_MENU_NEW_CLASS, CLASS_NAME_MAX_LEN );
+	str_nz_cpy( p[n].name, MSG_MENU_NEW_CLASS, CLASS_NAME_MAX_BYTE );
 	for( i = 0; i < ABL_KIND_MAX_N; i++ )
 		p[n].abl_rate[i] = (rate_t)0;
 	for( i = 0; i < SKILL_MAX_N; i++ )
@@ -2610,6 +2623,7 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 	edit_class_t	prev_n;
 	class_t	edit, *work;
 	bool_t	flg_sel_add;
+	bool_t	flg_sel;
 
 	n = static_exec_edit_class__n;
 
@@ -2636,6 +2650,8 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 
 		call_gui_class_edit_draw( work );
 
+		flg_sel = FALSE;
+
 		switch( get_key( g_flg_clr_key_buf_menu ) ){
 		case CASE_CANCEL:
 		case CASE_EXEC:
@@ -2647,38 +2663,13 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 			}
 			draw_edit_class_all( org, work, n, flg_sel_add );
 			break;
+		case ' ':
+			if( get_flg_space_select() )
+				flg_sel = TRUE;
+			break;
 		case CASE_ENTER:
-			if( n == EDIT_CLASS_NEXT ){
-				if( exec_menu_ask_edit_class(
-						org, work, flg_new ) ){
-					static_exec_edit_class__n = n;
-					return +1;
-				}
-				draw_edit_class_all( org, work, n,
-						flg_sel_add );
-				break;
-			} else if( n == EDIT_CLASS_PREV ){
-				if( exec_menu_ask_edit_class(
-						org, work, flg_new ) ){
-					static_exec_edit_class__n = n;
-					return -1;
-				}
-				draw_edit_class_all( org, work, n,
-						flg_sel_add );
-				break;
-			} else if( n == EDIT_CLASS_NAME ){
-				draw_edit_class( org, work, n,
-						FALSE, flg_sel_add );
-				gets_class_name( work->name );
-				break;
-			}
-
-			if( flg_sel_add )
-				menu_edit_class_inc_abl( work, n, +1 );
-			else
-				menu_edit_class_inc_abl( work, n, -1 );
-			draw_edit_class( org, work, EDIT_CLASS_TOTAL,
-					FALSE, flg_sel_add );
+			if( !get_flg_space_select() )
+				flg_sel = TRUE;
 			break;
 		case CASE_CRSR_LEFT:
 			flg_sel_add = TRUE;
@@ -2698,6 +2689,42 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 		default:
 			break;
 		}
+
+		if( flg_sel ){
+			if( n == EDIT_CLASS_NEXT ){
+				if( exec_menu_ask_edit_class(
+						org, work, flg_new ) ){
+					static_exec_edit_class__n = n;
+					return +1;
+				}
+				draw_edit_class_all( org, work, n,
+						flg_sel_add );
+			} else if( n == EDIT_CLASS_PREV ){
+				if( exec_menu_ask_edit_class(
+						org, work, flg_new ) ){
+					static_exec_edit_class__n = n;
+					return -1;
+				}
+				draw_edit_class_all( org, work, n,
+						flg_sel_add );
+			} else if( n == EDIT_CLASS_NAME ){
+				draw_edit_class( org, work, n,
+						FALSE, flg_sel_add );
+				gets_class_name( work->name );
+			} else {
+				if( flg_sel_add ){
+					menu_edit_class_inc_abl(
+							work, n, +1 );
+				} else {
+					menu_edit_class_inc_abl(
+							work, n, -1 );
+				}
+
+				draw_edit_class( org, work,
+						EDIT_CLASS_TOTAL,
+						FALSE, flg_sel_add );
+			}
+		}
 	}
 
 	static_exec_edit_class__n = n;
@@ -2711,6 +2738,7 @@ long	exec_edit_skill( class_t *org, bool_t flg_new )
 	edit_skill_t	*pn, prev_n;
 	class_t	edit, *work;
 	long	slot;
+	bool_t	flg_sel;
 
 	g_skill_slot_n = static_exec_edit_skill__n;
 
@@ -2737,6 +2765,8 @@ long	exec_edit_skill( class_t *org, bool_t flg_new )
 
 		call_gui_skill_edit_draw( work );
 
+		flg_sel = FALSE;
+
 		switch( get_key( g_flg_clr_key_buf_menu ) ){
 		case CASE_CANCEL:
 		case CASE_EXEC:
@@ -2748,43 +2778,13 @@ long	exec_edit_skill( class_t *org, bool_t flg_new )
 			}
 			draw_edit_skill_all( org, work, *pn );
 			break;
+		case ' ':
+			if( get_flg_space_select() )
+				flg_sel = TRUE;
+			break;
 		case CASE_ENTER:
-			if( *pn == EDIT_SKILL_NEXT ){
-				if( exec_menu_ask_edit_skill(
-						org, work, flg_new ) ){
-					static_exec_edit_skill__n = *pn;
-					return +1;
-				}
-				draw_edit_skill_all( org, work, *pn );
-				break;
-			} else if( *pn == EDIT_SKILL_PREV ){
-				if( exec_menu_ask_edit_skill(
-						org, work, flg_new ) ){
-					static_exec_edit_skill__n = *pn;
-					return -1;
-				}
-				draw_edit_skill_all( org, work, *pn );
-				break;
-			} else if( *pn == EDIT_SKILL_CLASS_NAME ){
-				draw_edit_skill( org, work, *pn, FALSE );
-				gets_class_name( work->name );
-				break;
-			} else if( (EDIT_SKILL_A_00 <= *pn)
-					&& (*pn <= EDIT_SKILL_A_09) ){
-				slot = *pn - EDIT_SKILL_A_00;
-
-				exec_sel_skill_edit( work, slot );
-				draw_edit_skill_all( org, work, *pn );
-				break;
-			} else if( (EDIT_SKILL_B_00 <= *pn)
-					&& (*pn <= EDIT_SKILL_B_09) ){
-				slot = *pn - EDIT_SKILL_B_00
-						+ SKILL_PER_PAGE_MAX_N;
-
-				exec_sel_skill_edit( work, slot );
-				draw_edit_skill_all( org, work, *pn );
-				break;
-			}
+			if( !get_flg_space_select() )
+				flg_sel = TRUE;
 			break;
 		case CASE_CRSR_LEFT:
 		case CASE_CRSR_RIGHT:
@@ -2801,6 +2801,40 @@ long	exec_edit_skill( class_t *org, bool_t flg_new )
 		default:
 			break;
 		}
+
+		if( flg_sel ){
+			if( *pn == EDIT_SKILL_NEXT ){
+				if( exec_menu_ask_edit_skill(
+						org, work, flg_new ) ){
+					static_exec_edit_skill__n = *pn;
+					return +1;
+				}
+				draw_edit_skill_all( org, work, *pn );
+			} else if( *pn == EDIT_SKILL_PREV ){
+				if( exec_menu_ask_edit_skill(
+						org, work, flg_new ) ){
+					static_exec_edit_skill__n = *pn;
+					return -1;
+				}
+				draw_edit_skill_all( org, work, *pn );
+			} else if( *pn == EDIT_SKILL_CLASS_NAME ){
+				draw_edit_skill( org, work, *pn, FALSE );
+				gets_class_name( work->name );
+			} else if( (EDIT_SKILL_A_00 <= *pn)
+					&& (*pn <= EDIT_SKILL_A_09) ){
+				slot = *pn - EDIT_SKILL_A_00;
+
+				exec_sel_skill_edit( work, slot );
+				draw_edit_skill_all( org, work, *pn );
+			} else if( (EDIT_SKILL_B_00 <= *pn)
+					&& (*pn <= EDIT_SKILL_B_09) ){
+				slot = *pn - EDIT_SKILL_B_00
+						+ SKILL_PER_PAGE_MAX_N;
+
+				exec_sel_skill_edit( work, slot );
+				draw_edit_skill_all( org, work, *pn );
+			}
+		}
 	}
 
 	static_exec_edit_skill__n = *pn;
@@ -2888,7 +2922,7 @@ char	*exec_sel_skill( skill_kind_t *ret_kind )
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg,
 				get_skill_group_name( (skill_group_kind_t)i ),
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
@@ -2903,7 +2937,7 @@ char	*exec_sel_skill( skill_kind_t *ret_kind )
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg,
 				get_skill_name_from_kind( kind ),
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_sel_skill;
 		p[k].arg = (void *)kind;
 		p[k].flg = FLG_NULL;
@@ -2926,7 +2960,7 @@ char	*exec_sel_skill( skill_kind_t *ret_kind )
 			p[k].short_key[0] = '\0';
 			str_nz_cpy( p[k].msg,
 					get_skill_name_from_kind( kind ),
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 			p[k].call_back = cb_menu_sel_skill;
 			p[k].arg = (void *)kind;
 			p[k].flg = FLG_NULL;
@@ -3177,10 +3211,7 @@ char	*cb_menu_load_bar( menu_t **pp, menu_t **dflt )
 {
 	menu_load_bar();
 
-/*@@@*/
 	return NULL;
-	return "/";
-	return "/bar";
 }
 
 /**/
@@ -3227,7 +3258,7 @@ char	*menu_inn( void )
 	p = srch_menu( ls_menu_inn, "stay" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_MENU_INN_STAY,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_MENU_INN_STAY,
 			fmt_gold( get_price_inn( FALSE ) ) );
 
 	/* ٷ */
@@ -3235,7 +3266,7 @@ char	*menu_inn( void )
 	p = srch_menu( ls_menu_inn, "short stay" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_MENU_INN_SHORT_STAY,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_MENU_INN_SHORT_STAY,
 			fmt_gold( get_price_inn( TRUE ) ) );
 
 	/* Ͼǰ */
@@ -3243,7 +3274,7 @@ char	*menu_inn( void )
 	p = srch_menu( ls_menu_inn, "stay in mews" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_MENU_INN_STAY_IN_MEWS,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_MENU_INN_STAY_IN_MEWS,
 			fmt_gold( 0 ) );
 
 	/**/
@@ -3343,6 +3374,9 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 {
 	menu_t	*ls, *p;
 	unsigned char	key;
+	spell_kind_t	kind;
+	spell_tab_t	*tab;
+	long	len, max_len;
 	bool_t	flg_no_enter;
 	gold_t	gold;
 	long	i;
@@ -3352,19 +3386,29 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 
 	ls = *pp;
 
+	max_len = 1;
+	for( i = 0; i < LOOP_MAX_1000; i++ ){
+		if( ls[i].path[0] == '\0' )
+			break;
+
+		kind = (spell_kind_t)(long)(ls[i].arg);
+		tab = get_spell_tab( kind );
+		if( tab != NULL ){
+			len = str_len_draw( tab->name );
+			max_len = max_l( len, max_len );
+		}
+	}
+
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_MAGIC_GUILD,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_TTL_MENU_MAGIC_GUILD,
 			get_shop_name( SHOP_N_MAGIC ),
 			g_sel_mbr->name,
 			fmt_gold( g_sel_mbr->gold ) );
 
 	key = 'A';
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
-		spell_kind_t	kind;
-		spell_tab_t	*tab;
-
 		if( ls[i].path[0] == '\0' )
 			break;
 		if( strcmp( ls[i].kind, "<PageSeparator>" ) == 0 ){
@@ -3384,18 +3428,20 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 		/**/
 
 		kind = (spell_kind_t)(long)(ls[i].arg);
-
 		tab = get_spell_tab( kind );
+
 		if( tab == NULL ){
 			gold = 0;
-			sn_printf( ls[i].msg, MENU_MSG_MAX_LEN,
+			sn_printf( ls[i].msg, MENU_MSG_MAX_BYTE,
 					MSG_FMT_MENU_MAGIC_GUILD,
-					"", 0, fmt_gold( 0 ) );
+					0, "", 0,
+					fmt_gold( 0 ) );
 		} else {
+			len = get_pading_len( tab->name, max_len );
 			gold = get_price_spell( kind );
-			sn_printf( ls[i].msg, MENU_MSG_MAX_LEN,
+			sn_printf( ls[i].msg, MENU_MSG_MAX_BYTE,
 					MSG_FMT_MENU_MAGIC_GUILD,
-					tab->name, tab->lev,
+					len, tab->name, tab->lev,
 					fmt_gold( gold ) );
 		}
 
@@ -3499,7 +3545,7 @@ char	*cb_menu_magic_guild( menu_t **pp, menu_t **dflt )
 	}
 
 	add_chr_gold( g_sel_mbr, -get_price_spell( kind ) );
-	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
+	call_game_sound_play( SOUND_KIND_SHOP_BUY, 1 );
 	set_chr_learned_spell( g_sel_mbr, kind, TRUE );
 
 	return "/magic guild";
@@ -3524,7 +3570,7 @@ char	*cb_menu_pet_shop_init( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE, MSG_TTL_MENU_PET_SHOP,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name,
 			fmt_gold( g_sel_mbr->gold ) );
@@ -3566,7 +3612,8 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP_TAKE,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
+			MSG_TTL_MENU_PET_SHOP_TAKE,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
@@ -3588,7 +3635,8 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		str_nz_cpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, ls_pet[i]->name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_pet_shop_take_sel;
 		ls[k].arg = (void *)(ls_pet[i]);
 		ls[k].flg = FLG_NULL;
@@ -3680,7 +3728,8 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP_LEAVE,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
+			MSG_TTL_MENU_PET_SHOP_LEAVE,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
@@ -3702,7 +3751,8 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		str_nz_cpy( ls[k].msg, party_pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, party_pet[i]->name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_pet_shop_leave_sel;
 		ls[k].arg = (void *)(party_pet[i]);
 		ls[k].flg = FLG_NULL;
@@ -3776,7 +3826,7 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 	k = 0;
 	key = 'A';
 	n = 0;
-	max_n = PET_MAX_N;
+	max_n = LS_PET_MAX_N;
 
 	str_nz_cpy( ls[k].path, "/pet shop name", MENU_PATH_MAX_LEN );
 	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
@@ -3789,12 +3839,14 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	str_nz_cpy( ls[k].path, "/pet shop name/title", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/pet shop name/title",
+			MENU_PATH_MAX_LEN );
 	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP_NAME,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
+			MSG_TTL_MENU_PET_SHOP_NAME,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
@@ -3819,7 +3871,7 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 				MSG_MENU_PET_SHOP_NAME_LS,
 				ls_pet[i]->name, mnstr_name );
 		ls[k].call_back = cb_menu_pet_shop_name_sel;
@@ -3916,7 +3968,7 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_PET_SHOP_REMOVE,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name );
@@ -3937,7 +3989,7 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		str_nz_cpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, ls_pet[i]->name, MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_pet_shop_remove_sel;
 		ls[k].arg = (void *)(ls_pet[i]);
 		ls[k].flg = FLG_NULL;
@@ -4018,6 +4070,8 @@ char	*cb_menu_pet_shop_remove_sel( menu_t **pp, menu_t **dflt )
 char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 {
 	art_ls_pet_shop_t	*art_ls_pet_shop;
+	long	len, max_len;
+	const char	*name;
 	menu_t	*ls;
 	long	k;
 	long	i, max_n;
@@ -4046,7 +4100,7 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE, MSG_TTL_MENU_PET_SHOP,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name,
 			fmt_gold( g_sel_mbr->gold ) );
@@ -4055,6 +4109,16 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
+	max_len = 1;
+	for( i = 0; i < max_n; i++ ){
+		if( art_ls_pet_shop[i].kind == MNSTR_KIND_NULL )
+			break;
+
+		name = get_mnstr_name( art_ls_pet_shop[i].kind );
+		len = str_len_draw( name );
+		max_len = max_l( len, max_len );
+	}
+
 	for( i = 0; i < max_n; i++ ){
 		if( art_ls_pet_shop[i].kind == MNSTR_KIND_NULL )
 			break;
@@ -4083,9 +4147,11 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+		name = get_mnstr_name( art_ls_pet_shop[i].kind );
+		len = get_pading_len( name, max_len );
+		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 				MSG_FMT_MENU_PET_SHOP,
-				get_mnstr_name( art_ls_pet_shop[i].kind ),
+				len, name,
 				fmt_gold( art_ls_pet_shop[i].price ) );
 		ls[k].call_back = cb_menu_pet_shop_buy_sel;
 		ls[k].arg = (void *)i;
@@ -4155,7 +4221,7 @@ char	*cb_menu_pet_shop_buy_sel( menu_t **pp, menu_t **dflt )
 	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_BUY_SUCCESS, pet->name );
 
 	add_chr_gold( g_sel_mbr, (gold_t)(-price) );
-	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
+	call_game_sound_play( SOUND_KIND_SHOP_BUY, 1 );
 
 	return "/pet shop";
 }
@@ -4197,7 +4263,7 @@ char	*cb_menu_navi_init( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_NAVI, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_NAVI, MENU_MSG_MAX_BYTE );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -4227,7 +4293,8 @@ char	*cb_menu_navi_init( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = toupper( mnr );
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		str_nz_cpy( ls[k].msg, get_shop_name( n ), MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, get_shop_name( n ),
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_navi;
 		ls[k].arg = (void *)n;
 		ls[k].flg = FLG_NULL;
@@ -4328,7 +4395,7 @@ bool_t	set_menu_auto_sale( menu_t *ls, mbr_t *mbr )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_SALE, mbr->name );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
@@ -4371,11 +4438,11 @@ bool_t	set_menu_auto_sale( menu_t *ls, mbr_t *mbr )
 		ls[k].accel_key = toupper( (char)('A' + i) );
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
+		len = get_pading_len( item->art_name, max_len );
 		sn_printf( ls[k].msg,
-				MENU_MSG_MAX_LEN,
+				MENU_MSG_MAX_BYTE,
 				MSG_FMT_ART_NAME,
-				max_len,
-				item->art_name,
+				len, item->art_name,
 				fmt_gold( price ) );
 		ls[k].call_back = cb_menu_auto_sale_chk;
 		ls[k].arg = (void *)item;
@@ -4463,7 +4530,7 @@ char	*cb_menu_auto_sale_exec( menu_t **pp, menu_t **dflt )
 	if( sale_sum <= 0 )
 		return NULL;
 
-	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
+	call_game_sound_play( SOUND_KIND_SHOP_SALE, 1 );
 
 	add_turn( NAVI_ADD_TURN_N + SHOP_ADD_TURN_N );
 
@@ -4486,3 +4553,24 @@ void	set_cur_shop_n( shop_n_t n )
 
 /**/
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_tmenu_c( void )
+{
+	check_memory( check_memory_tmenu_c_g_sel_mbr,
+			"tmenu.c: g_sel_mbr" );
+	check_memory( check_memory_tmenu_c_g_shop_n,
+			"tmenu.c: g_shop_n" );
+	check_memory( check_memory_tmenu_c_g_mbr_order,
+			"tmenu.c: g_mbr_order" );
+	check_memory( check_memory_tmenu_c_g_navi_dflt,
+			"tmenu.c: g_navi_dflt" );
+	check_memory( check_memory_tmenu_c_static_exec_edit_class__n,
+			"tmenu.c: static_exec_edit_class__n" );
+	check_memory( check_memory_tmenu_c_g_sel_skill_kind,
+			"tmenu.c: g_sel_skill_kind" );
+}
+
+/**/
